@@ -1008,7 +1008,9 @@ src_frontends_qt4_moc_files = Split('''
     EmptyTable.cpp
     FloatPlacement.cpp
     GuiApplication.cpp
+    GuiClipboard.cpp
     GuiImplementation.cpp
+    GuiSelection.cpp
     GuiView.cpp
     GuiWorkArea.cpp
     IconPalette.cpp
@@ -1312,6 +1314,7 @@ intl_files = Split('''
     gettext.c
     intl-compat.c
     l10nflist.c
+    langprefs.c
     loadmsgcat.c
     localcharset.c
     localealias.c
@@ -1529,6 +1532,7 @@ lib_fonts_files = Split('''
     cmmi10.ttf
     cmr10.ttf
     cmsy10.ttf
+    esint10.ttf
     eufm10.ttf
     msam10.ttf
     msbm10.ttf
@@ -2217,23 +2221,41 @@ lib_doc_files = Split('''
 ''')
 
 
+lib_doc_biblio_files = Split('''
+    alphadin.bst
+    LyXDocs.bib
+''')
+
+
 lib_doc_clipart_files = Split('''
+    Abstract.pdf
     BoxInsetDefaultQt4.png
+    ChangesToolbar.png
     ChildDocumentQt4.png
     CommentNoteImageQt4.png
+    ERT.png
     ExternalMaterialQt4.png
+    ExtraToolbar.png
     FramedNoteImageQt4.png
     GreyedOutNoteImageQt4.png
+    LaTeX.png
     LyXNoteImageQt4.png
     ShadedNoteImageQt4.png
+    SpaceMarker.png
+    StandardToolbar.png
+    ToolbarEnvBox.png
     endnotes.pdf
     escher-lsd.eps
     floatQt4.png
     footnoteQt4.png
     labelQt4.png
+    macrobox.png
+    macrouse.png
+    mbox.png
     mobius.eps
     platypus.eps
     referenceQt4.png
+    ViewToolbar.png
     with_fntright.pdf
     without_fntright.pdf
 ''')
@@ -2269,6 +2291,7 @@ lib_doc_de_files = Split('''
 
 
 lib_doc_de_clipart_files = Split('''
+    ERT.png
     ExternesMaterialQt4.png
     FussnoteQt4.png
     GerahmteNotizQt4.png
@@ -2297,6 +2320,13 @@ lib_doc_es_files = Split('''
     Extended.lyx
     Intro.lyx
     Tutorial.lyx
+    UserGuide.lyx
+''')
+
+
+lib_doc_es_biblio_files = Split('''
+    alphadin.bst
+    LyXDocs.bib
 ''')
 
 
@@ -2309,6 +2339,8 @@ lib_doc_es_clipart_files = Split('''
     NotaEnmarcadaImg.png
     NotaLyXImagenQt4.png
     NotaSombreadaImg.png
+    Resumen.pdf
+    es_ERT.png
     etiquetaQt4.png
     flotanteQt4.png
     notapieQt4.png
@@ -2328,6 +2360,7 @@ lib_doc_eu_files = Split('''
 
 lib_doc_fr_files = Split('''
     Customization.lyx
+    EmbeddedObjects.lyx
     Extended.lyx
     FAQ.lyx
     Intro.lyx
@@ -2336,6 +2369,20 @@ lib_doc_fr_files = Split('''
 ''')
 
 
+lib_doc_fr_clipart_files = Split('''
+    BoxInsetDefaultQt4.png
+    ChildDocumentQt4.png
+    CommentNoteImageQt4.png
+    FramedNoteImageQt4.png
+    GreyedOutNoteImageQt4.png
+    LyXNoteImageQt4.png
+    ShadedNoteImageQt4.png
+    floatQt4.png
+    footnoteQt4.png
+    labelQt4.png
+''')
+
+
 lib_doc_gl_extra_files = Split('''
     Intro.lyx
     Tutorial.lyx
@@ -2443,7 +2490,6 @@ lib_examples_files = Split('''
     biblioExample.bib
     chess-article.lyx
     chessgame.lyx
-    currency.lyx
     docbook_article.lyx
     europeCV.lyx
     example_lyxified.lyx
@@ -2485,8 +2531,6 @@ lib_examples_de_files = Split('''
     ItemizeBullets.lyx
     Lebenslauf.lyx
     Minipage.lyx
-    TabellenBeispiel.lyx
-    Waehrungen.lyx
     beispiel_gelyxt.lyx
     beispiel_roh.lyx
     mathed.lyx
@@ -2502,8 +2546,6 @@ lib_examples_fa_files = Split('''
 
 lib_examples_fr_files = Split('''
     AlignementDecimal.lyx
-    simplecv.lyx
-    ExemplesTableaux.lyx
     Foils.lyx
     ListesPuces.lyx
     Minipage.lyx
@@ -2511,11 +2553,13 @@ lib_examples_fr_files = Split('''
     exemple_lyxifie.lyx
     mathed.lyx
     multicol.lyx
+    simplecv.lyx
     splash.lyx
 ''')
 
 
 lib_examples_es_files = Split('''
+    ItemizeBullets.lyx
     ejemplo_con_lyx.lyx
     ejemplo_sin_lyx.lyx
     splash.lyx
