@@ -539,7 +539,7 @@ class LyX_Base:
                     k = k + 1
 
             # trim empty lines in the end.
-            while par[-1].strip() == '' and par:
+            while par and par[-1].strip() == '':
                 par.pop()
 
             toc_par.append(Paragraph(section, par))
