@@ -103,6 +103,7 @@ using std::pair;
 using std::stack;
 using std::vector;
 using std::string;
+using std::time_t;
 
 
 namespace lyx {
@@ -131,6 +132,8 @@ using support::split;
 using support::subst;
 using support::tempName;
 using support::trim;
+using support::sum;
+using support::suffixIs;
 
 namespace Alert = frontend::Alert;
 namespace os = support::os;
@@ -192,13 +195,18 @@ public:
 
 	/// Container for all sort of Buffer dependant errors.
 	map<string, ErrorList> errorLists;
+
+	/// timestamp and checksum used to test if the file has been externally
+	/// modified. (Used to properly enable 'File->Revert to saved', bug 4114).
+	time_t timestamp_;
+	unsigned long checksum_;
 };
 
 
 Buffer::Impl::Impl(Buffer & parent, FileName const & file, bool readonly_)
 	: lyx_clean(true), bak_clean(true), unnamed(false), read_only(readonly_),
 	  filename(file), file_fully_loaded(false), inset(params),
-	  toc_backend(&parent)
+	  toc_backend(&parent), timestamp_(0), checksum_(0)
 {
 	inset.setAutoBreakRows(true);
 	lyxvc.buffer(&parent);
@@ -689,6 +697,19 @@ Buffer::ReadStatus Buffer::readFile(Lexer & lex, FileName const & filename,
 	int const file_format = convert<int>(tmp_format);
 	//lyxerr << "format: " << file_format << endl;
 
+	// save timestamp and checksum of the original disk file, making sure
+	// to not overwrite them with those of the file created in the tempdir
+	// when it has to be converted to the current format.
+	if (!pimpl_->checksum_) {
+		// Save the timestamp and checksum of disk file. If filename is an
+		// emergency file, save the timestamp and sum of the original lyx file
+		// because isExternallyModified will check for this file. (BUG4193)
+		string diskfile = filename.absFilename();
+		if (suffixIs(diskfile, ".emergency"))
+			diskfile = diskfile.substr(0, diskfile.size() - 10);
+		saveCheckSum(FileName(diskfile));
+	}
+
 	if (file_format != LYX_FORMAT) {
 
 		if (fromstring)
@@ -773,10 +794,13 @@ bool Buffer::save() const
 	// make a backup if the file already exists
 	if (lyxrc.make_backup && fs::exists(encodedFilename)) {
 		backupName = FileName(fileName() + '~');
-		if (!lyxrc.backupdir_path.empty())
+		if (!lyxrc.backupdir_path.empty()) {
+			string const mangledName =
+				subst(subst(os::internal_path(
+				backupName.absFilename()), '/', '!'), ':', '!');
 			backupName = FileName(addName(lyxrc.backupdir_path,
-					      subst(os::internal_path(backupName.absFilename()), '/', '!')));
-
+						      mangledName));
+		}
 		try {
 			fs::copy_file(encodedFilename, backupName.toFilesystemEncoding(), false);
 			madeBackup = true;
@@ -789,9 +813,21 @@ bool Buffer::save() const
 		}
 	}
 
+	// ask if the disk file has been externally modified (use checksum method)
+	if (fs::exists(encodedFilename) && isExternallyModified(checksum_method)) {
+		docstring const file = makeDisplayPath(fileName(), 20);
+		docstring text = bformat(_("Document %1$s has been externally modified. Are you sure "
+							     "you want to overwrite this file?"), file);
+		int const ret = Alert::prompt(_("Overwrite modified file?"),
+			text, 1, 1, _("&Overwrite"), _("&Cancel"));
+		if (ret == 1)
+			return false;
+	}
+
 	if (writeFile(pimpl_->filename)) {
 		markClean();
 		removeAutosaveFile(fileName());
+		saveCheckSum(pimpl_->filename);
 		return true;
 	} else {
 		// Saving failed, so backup is not backup
@@ -911,7 +947,7 @@ bool Buffer::makeLaTeXFile(FileName const & fname,
 		lyxerr << "Caught iconv exception: " << e.what() << endl;
 		failed_export = true;
 	}
-	catch (std::exception  const & e) {
+	catch (std::exception const & e) {
 		lyxerr << "Caught \"normal\" exception: " << e.what() << endl;
 		failed_export = true;
 	}
@@ -1270,6 +1306,10 @@ void Buffer::validate(LaTeXFeatures & features) const
 		}
 	}
 
+	// Floats with 'Here definitely' as default setting.
+	if (params().float_placement.find('H') != string::npos)
+		features.require("float");
+
 	// AMS Style is at document level
 	if (params().use_amsmath == BufferParams::package_on
 	    || tclass.provides("amsmath"))
@@ -1556,6 +1596,30 @@ bool Buffer::isBakClean() const
 }
 
 
+bool Buffer::isExternallyModified(CheckMethod method) const
+{
+	BOOST_ASSERT(fs::exists(pimpl_->filename.toFilesystemEncoding()));
+	// if method == timestamp, check timestamp before checksum
+	return (method == checksum_method 
+		|| pimpl_->timestamp_ != fs::last_write_time(pimpl_->filename.toFilesystemEncoding()))
+		&& pimpl_->checksum_ != sum(pimpl_->filename);
+}
+
+
+void Buffer::saveCheckSum(FileName const & file) const
+{
+	if (fs::exists(file.toFilesystemEncoding())) {
+		pimpl_->timestamp_ =
+			fs::last_write_time(file.toFilesystemEncoding());
+		pimpl_->checksum_ = sum(file);
+	} else {
+		// in the case of save to a new file.
+		pimpl_->timestamp_ = 0;
+		pimpl_->checksum_ = 0;
+	}
+}
+
+
 void Buffer::markClean() const
 {
 	if (!pimpl_->lyx_clean) {
@@ -1654,7 +1718,10 @@ Buffer * Buffer::getMasterBuffer()
 	if (!params().parentname.empty()
 	    && theBufferList().exists(params().parentname)) {
 		Buffer * buf = theBufferList().getBuffer(params().parentname);
-		if (buf)
+		//We need to check if the parent is us...
+		//FIXME RECURSIVE INCLUDE
+		//This is not sufficient, since recursive includes could be downstream.
+		if (buf && buf != this)
 			return buf->getMasterBuffer();
 	}
 
@@ -1767,7 +1834,7 @@ void Buffer::getSourceCode(odocstream & os, pit_type par_begin,
 		runparams.par_end = par_end;
 		if (par_begin + 1 == par_end)
 			os << "% "
-			   << bformat(_("Preview source code for paragraph %1$s"), par_begin)
+			   << bformat(_("Preview source code for paragraph %1$d"), par_begin)
 			   << "\n\n";
 		else
 			os << "% "
