@@ -50,6 +50,7 @@
 using std::endl;
 using std::string;
 using std::istringstream;
+using std::make_pair;
 using std::ostream;
 using std::ostringstream;
 using std::pair;
@@ -454,16 +455,20 @@ string const BufferParams::readToken(Lexer & lex, string const & token)
 	if (token == "\\textclass") {
 		lex.next();
 		string const classname = lex.getString();
+		// if there exists a local layout file, ignore the system one
+		// NOTE: in this case, the textclass (.cls file) is assumed to be available.
 		pair<bool, lyx::textclass_type> pp =
-			textclasslist.numberOfClass(classname);
-		if (pp.first) {
-			textclass = pp.second;
-		} else {
-			// if text class does not exist, try to load it from filepath
+			make_pair(false, textclass_type(0));
+		if (!filepath.empty())
 			pp = textclasslist.addTextClass(classname, filepath);
-			if (pp.first) {
+		if (pp.first)
+			textclass = pp.second;
+		else  {
+			pp = textclasslist.numberOfClass(classname);
+			if (pp.first)
 				textclass = pp.second;
-			} else {
+			else {
+				// a warning will be given for unknown class
 				textclass = defaultTextclass();
 				return classname;
 			}
@@ -1406,7 +1411,7 @@ void BufferParams::writeEncodingPreamble(odocstream & os,
 			os << "]{inputenc}\n";
 			texrow.newline();
 		}
-		if (package == Encoding::CJK) {
+		if (package == Encoding::CJK || features.mustProvide("CJK")) {
 			os << "\\usepackage{CJK}\n";
 			texrow.newline();
 		}
