@@ -49,7 +49,6 @@
 #include "ParagraphParameters.h"
 #include "ParIterator.h"
 #include "TexRow.h"
-#include "toc.h"
 #include "Undo.h"
 #include "VSpace.h"
 #include "WordLangTuple.h"
@@ -126,7 +125,7 @@ BufferView::BufferView()
 	: width_(0), height_(0), buffer_(0), wh_(0),
 	  cursor_(*this),
 	  multiparsel_cache_(false), anchor_ref_(0), offset_ref_(0),
-	  intl_(new Intl), last_inset_(0)
+	  need_centering_(false), intl_(new Intl), last_inset_(0)
 {
 	xsel_cache_.set = false;
 	intl_->initKeyMapper(lyxrc.use_kbmap);
@@ -546,6 +545,7 @@ boost::tuple<pit_type, pos_type, int> BufferView::moveToPosition(pit_type bottom
 					break;
 				}
 			setCursor(dit);
+			cursor_.text()->setCurrentFont(cursor_);
 			// Note: return bottom (document) level pit.
 			return boost::make_tuple(cursor_.bottom().pit(), cursor_.bottom().pos(), top_id);
 		}
@@ -561,6 +561,7 @@ boost::tuple<pit_type, pos_type, int> BufferView::moveToPosition(pit_type bottom
 		it.pit() = bottom_pit;
 		it.pos() = min(bottom_pos, it.paragraph().size());
 		setCursor(it);
+		cursor_.text()->setCurrentFont(cursor_);
 		return boost::make_tuple(it.pit(), it.pos(),
 					 it.paragraph().id());
 	}
@@ -591,16 +592,31 @@ int BufferView::workWidth() const
 }
 
 
-void BufferView::center()
+void BufferView::updateOffsetRef()
 {
+	// No need to update offset_ref_ in this case.
+	if (!need_centering_)
+		return;
+
+	// We are not properly started yet, delay until resizing is
+	// done.
+	if (height_ == 0)
+		return;
+
 	CursorSlice & bot = cursor_.bottom();
 	TextMetrics & tm = text_metrics_[bot.text()];
-	pit_type const pit = bot.pit();
-	tm.redoParagraph(pit);
-	ParagraphMetrics const & pm = tm.parMetrics(pit);
-	anchor_ref_ = pit;
-	offset_ref_ = bv_funcs::coordOffset(*this, cursor_, cursor_.boundary()).y_
-		+ pm.ascent() - height_ / 2;
+	ParagraphMetrics const & pm = tm.parMetrics(bot.pit());
+	Point p = bv_funcs::coordOffset(*this, cursor_, cursor_.boundary());
+	offset_ref_ = p.y_ + pm.ascent() - height_ / 2;
+
+	need_centering_ = false;
+}
+
+
+void BufferView::center()
+{
+	anchor_ref_ = cursor_.bottom().pit();
+	need_centering_ = true;
 }
 
 
@@ -628,11 +644,6 @@ FuncStatus BufferView::getStatus(FuncRequest const & cmd)
 	case LFUN_FONT_STATE:
 	case LFUN_LABEL_INSERT:
 	case LFUN_PARAGRAPH_GOTO:
-	// FIXME handle non-trivially
-	case LFUN_OUTLINE_UP:
-	case LFUN_OUTLINE_DOWN:
-	case LFUN_OUTLINE_IN:
-	case LFUN_OUTLINE_OUT:
 	case LFUN_NOTE_NEXT:
 	case LFUN_REFERENCE_NEXT:
 	case LFUN_WORD_FIND:
@@ -803,25 +814,6 @@ Update::flags BufferView::dispatch(FuncRequest const & cmd)
 		break;
 	}
 
-	case LFUN_OUTLINE_UP:
-		toc::outline(toc::Up, cursor_);
-		cursor_.text()->setCursor(cursor_, cursor_.pit(), 0);
-		updateLabels(*buffer_);
-		break;
-	case LFUN_OUTLINE_DOWN:
-		toc::outline(toc::Down, cursor_);
-		cursor_.text()->setCursor(cursor_, cursor_.pit(), 0);
-		updateLabels(*buffer_);
-		break;
-	case LFUN_OUTLINE_IN:
-		toc::outline(toc::In, cursor_);
-		updateLabels(*buffer_);
-		break;
-	case LFUN_OUTLINE_OUT:
-		toc::outline(toc::Out, cursor_);
-		updateLabels(*buffer_);
-		break;
-
 	case LFUN_NOTE_NEXT:
 		bv_funcs::gotoInset(this, Inset::NOTE_CODE, false);
 		break;
@@ -1003,12 +995,16 @@ Update::flags BufferView::dispatch(FuncRequest const & cmd)
 		// if there is an inset at cursor, see whether it
 		// wants to toggle.
 		Inset * inset = cur.nextInset();
-		if (inset && inset->isActive()) {
-			Cursor tmpcur = cur;
-			tmpcur.pushLeft(*inset);
-			inset->dispatch(tmpcur, tmpcmd);
-			if (tmpcur.result().dispatched()) {
-				cur.dispatched();
+		if (inset) {
+			if (inset->isActive()) {
+				Cursor tmpcur = cur;
+				tmpcur.pushLeft(*inset);
+				inset->dispatch(tmpcur, tmpcmd);
+				if (tmpcur.result().dispatched()) {
+					cur.dispatched();
+				}
+			} else if (inset->editable() == Inset::IS_EDITABLE) {
+				inset->edit(cur, true);
 			}
 		}
 		// if it did not work, try the underlying inset.
@@ -1076,9 +1072,6 @@ void BufferView::workAreaResize(int width, int height)
 	width_ = width;
 	height_ = height;
 
-	// The complete text metrics will be redone.
-	text_metrics_.clear();
-
 	if (buffer_)
 		resize();
 }
@@ -1443,7 +1436,6 @@ ViewMetricsInfo const & BufferView::viewMetricsInfo()
 void BufferView::updateMetrics(bool singlepar)
 {
 	Text & buftext = buffer_->text();
-	TextMetrics & tm = textMetrics(&buftext);
 	pit_type size = int(buftext.paragraphs().size());
 
 	if (anchor_ref_ > int(buftext.paragraphs().size() - 1)) {
@@ -1457,18 +1449,27 @@ void BufferView::updateMetrics(bool singlepar)
 	
 		// Clear out paragraph metrics to avoid having invalid metrics
 		// in the cache from paragraphs not relayouted below
-		tm.clear();
+		// The complete text metrics will be redone.
+		text_metrics_.clear();
 	}
 
+	TextMetrics & tm = textMetrics(&buftext);
+
 	// If the paragraph metrics has changed, we can not
 	// use the singlepar optimisation.
-	if (singlepar
+	if (singlepar) {
+		pit_type const bottom_pit = cursor_.bottom().pit();
+		int old_height = tm.parMetrics(bottom_pit).height();
 		// In Single Paragraph mode, rebreak only
 		// the (main text, not inset!) paragraph containing the cursor.
 		// (if this paragraph contains insets etc., rebreaking will
 		// recursively descend)
-		&& tm.redoParagraph(cursor_.bottom().pit()))
-		singlepar = false;
+		tm.redoParagraph(bottom_pit);
+		// Paragraph height has changed so we cannot proceed to
+		// the singlePar optimisation.
+		if (tm.parMetrics(bottom_pit).height() != old_height)
+			singlepar = false;
+	}
 
 	pit_type const pit = anchor_ref_;
 	int pit1 = pit;
@@ -1479,6 +1480,8 @@ void BufferView::updateMetrics(bool singlepar)
 	if (!singlepar)
 		tm.redoParagraph(pit);
 
+	updateOffsetRef();
+
 	int y0 = tm.parMetrics(pit).ascent() - offset_ref_;
 
 	// Redo paragraphs above anchor if necessary.
