@@ -187,6 +187,20 @@ static string const changetracking_none_def =
 	"\\newcommand{\\lyxadded}[3]{#3}\n"
 	"\\newcommand{\\lyxdeleted}[3]{}\n";
 
+static string const textgreek_def =
+	"\\DeclareRobustCommand{\\greektext}{%\n"
+	" \\fontencoding{LGR}\\selectfont\n"
+	" \\def\\encodingdefault{LGR}}\n"
+	"\\DeclareRobustCommand{\\textgreek}[1]{\\leavevmode{\\greektext #1}}\n"
+	"\\DeclareFontEncoding{LGR}{}{}\n";
+
+static string const textcyr_def =
+	"\\DeclareRobustCommand{\\cyrtext}{%\n"
+	" \\fontencoding{T2A}\\selectfont\n"
+	" \\def\\encodingdefault{T2A}}\n"
+	"\\DeclareRobustCommand{\\textcyr}[1]{\\leavevmode{\\cyrtext #1}}\n"
+	"\\AtBeginDocument{\\DeclareFontEncoding{T2A}{}{}}\n";
+
 
 /////////////////////////////////////////////////////////////////////
 //
@@ -340,6 +354,10 @@ void LaTeXFeatures::useLanguage(Language const * lang)
 {
 	if (!lang->babel().empty())
 		UsedLanguages_.insert(lang);
+	// CJK languages do not have a babel name.
+	// They use the CJK package
+	if (lang->encoding()->package() == Encoding::CJK)
+		require("CJK");
 }
 
 
@@ -419,6 +437,7 @@ char const * simplefeatures[] = {
 	"txfonts",
 	"mathrsfs",
 	"ascii",
+	"url",
 };
 
 int const nb_simplefeatures = sizeof(simplefeatures) / sizeof(char const *);
@@ -547,11 +566,6 @@ string const LaTeXFeatures::getPackages() const
 	    params_.use_esint != BufferParams::package_off)
 		packages << "\\usepackage{esint}\n";
 
-	// url.sty
-	if (mustProvide("url"))
-		packages << "\\IfFileExists{url.sty}{\\usepackage{url}}\n"
-			    "                      {\\newcommand{\\url}{\\texttt}}\n";
-
 	// natbib.sty
 	if (mustProvide("natbib")) {
 		packages << "\\usepackage[";
@@ -619,6 +633,12 @@ string const LaTeXFeatures::getMacros() const
 	if (mustProvide("lyxarrow"))
 		macros << lyxarrow_def << '\n';
 
+	if (mustProvide("textgreek"))
+		macros << textgreek_def << '\n';
+
+	if (mustProvide("textcyr"))
+		macros << textcyr_def << '\n';
+
 	// quotes.
 	if (mustProvide("quotesinglbase"))
 		macros << quotesinglbase_def << '\n';
