@@ -496,7 +496,8 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 		enable = buf->lyxvc().inUse();
 		break;
 	case LFUN_BUFFER_RELOAD:
-		enable = !buf->isUnnamed() && !buf->isClean();
+		enable = !buf->isUnnamed() && fs::exists(buf->fileName())
+			&& (!buf->isClean() || buf->isExternallyModified(Buffer::timestamp_method));
 		break;
 
 	case LFUN_INSET_SETTINGS: {
@@ -612,6 +613,29 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 		break;
 	}
 
+
+	case LFUN_BUFFER_WRITE_ALL: {
+	// We enable the command only if there are some modified buffers
+		Buffer * first = theBufferList().first();
+		bool modified = false;
+		if (first) {
+			Buffer * b = first;
+		
+		// We cannot use a for loop as the buffer list is a cycle.
+			do {
+				if (!b->isClean()) {
+					modified = true;
+					break;
+				}
+				b = theBufferList().next(b);
+			} while (b != first); 
+		}
+	
+		enable = modified;
+
+		break;
+	}
+
 	case LFUN_BOOKMARK_GOTO: {
 		const unsigned int num = convert<unsigned int>(to_utf8(cmd.argument()));
 		enable = LyX::ref().session().bookmarks().isValid(num);
@@ -654,6 +678,8 @@ FuncStatus LyXFunc::getStatus(FuncRequest const & cmd) const
 	case LFUN_BUFFER_WRITE_AS:
 	case LFUN_BUFFER_UPDATE:
 	case LFUN_BUFFER_VIEW:
+	case LFUN_MASTER_BUFFER_UPDATE:
+	case LFUN_MASTER_BUFFER_VIEW:
 	case LFUN_BUFFER_IMPORT:
 	case LFUN_BUFFER_AUTO_SAVE:
 	case LFUN_RECONFIGURE:
@@ -907,6 +933,30 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			updateFlags = Update::None;
 			break;
 
+		case LFUN_BUFFER_WRITE_ALL: {
+			Buffer * first = theBufferList().first();
+			if (first) {
+				Buffer * b = first;
+				lyx_view_->message(_("Saving all documents..."));
+		
+				// We cannot use a for loop as the buffer list cycles.
+				do {
+					if (!b->isClean()) {
+						if (!b->isUnnamed()) {
+							menuWrite(b);
+							lyxerr[Debug::ACTION] << "Saved " << b->fileName() << endl;
+						} else
+							writeAs(b);
+					}
+					b = theBufferList().next(b);
+				} while (b != first); 
+				lyx_view_->message(_("All documents saved."));
+			} 
+	
+			updateFlags = Update::None;
+			break;
+		}
+
 		case LFUN_BUFFER_RELOAD: {
 			BOOST_ASSERT(lyx_view_ && lyx_view_->buffer());
 			docstring const file = makeDisplayPath(view()->buffer()->fileName(), 20);
@@ -930,6 +980,16 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			Exporter::preview(lyx_view_->buffer(), argument);
 			break;
 
+		case LFUN_MASTER_BUFFER_UPDATE:
+			BOOST_ASSERT(lyx_view_ && lyx_view_->buffer() && lyx_view_->buffer()->getMasterBuffer());
+			Exporter::Export(lyx_view_->buffer()->getMasterBuffer(), argument, true);
+			break;
+
+		case LFUN_MASTER_BUFFER_VIEW:
+			BOOST_ASSERT(lyx_view_ && lyx_view_->buffer() && lyx_view_->buffer()->getMasterBuffer());
+			Exporter::preview(lyx_view_->buffer()->getMasterBuffer(), argument);
+			break;
+
 		case LFUN_BUILD_PROGRAM:
 			BOOST_ASSERT(lyx_view_ && lyx_view_->buffer());
 			Exporter::Export(lyx_view_->buffer(), "program", true);
@@ -1118,7 +1178,8 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 
 		case LFUN_RECONFIGURE:
 			BOOST_ASSERT(lyx_view_);
-			reconfigure(*lyx_view_);
+			// argument is any additional parameter to the configure.py command
+			reconfigure(*lyx_view_, argument);
 			break;
 
 		case LFUN_HELP_OPEN: {
@@ -2298,6 +2359,7 @@ void actOnUpdatedPrefs(LyXRC const & lyxrc_orig, LyXRC const & lyxrc_new)
 	case LyXRC::RC_USE_ESC_CHARS:
 	case LyXRC::RC_USE_INP_ENC:
 	case LyXRC::RC_USE_PERS_DICT:
+	case LyXRC::RC_USE_PIXMAP_CACHE:
 	case LyXRC::RC_USE_SPELL_LIB:
 	case LyXRC::RC_VIEWDVI_PAPEROPTION:
 	case LyXRC::RC_VIEWER:
