@@ -164,6 +164,7 @@ keyword_item lyxrcTags[] = {
 	{ "\\use_input_encoding", LyXRC::RC_USE_INP_ENC },
 	{ "\\use_lastfilepos", LyXRC::RC_USELASTFILEPOS },
 	{ "\\use_personal_dictionary", LyXRC::RC_USE_PERS_DICT },
+	{ "\\use_pixmap_cache", LyXRC::RC_USE_PIXMAP_CACHE },
 	// compatibility with versions older than 1.4.0 only
 	{ "\\use_pspell", LyXRC::RC_USE_SPELL_LIB },
 	{ "\\use_spell_lib", LyXRC::RC_USE_SPELL_LIB },
@@ -278,6 +279,7 @@ void LyXRC::setDefaults() {
 	preview_hashed_labels  = false;
 	preview_scale_factor = "0.9";
 	use_converter_cache = true;
+	use_pixmap_cache = false;
 	converter_cache_maxage = 6 * 30 * 24 * 3600; // 6 months
 
 	user_name = to_utf8(support::user_name());
@@ -893,6 +895,11 @@ int LyXRC::read(Lexer & lexrc)
 				isp_use_pers_dict = lexrc.getBool();
 			}
 			break;
+		case RC_USE_PIXMAP_CACHE:
+			if (lexrc.next()) {
+				use_pixmap_cache = lexrc.getBool();
+			}
+			break;
 		case RC_USE_ESC_CHARS:
 			if (lexrc.next()) {
 				isp_use_esc_chars = lexrc.getBool();
@@ -1869,6 +1876,13 @@ void LyXRC::write(ostream & os, bool ignore_system_lyxrc) const
 			   << convert<string>(isp_use_pers_dict)
 			   << '\n';
 		}
+	case RC_USE_PIXMAP_CACHE:
+		if (ignore_system_lyxrc ||
+		    use_pixmap_cache != system_lyxrc.use_pixmap_cache) {
+			os << "\\use_pixmap_cache "
+			   << convert<string>(use_pixmap_cache)
+			   << '\n';
+		}
 	case RC_PERS_DICT:
 		if (isp_pers_dict != system_lyxrc.isp_pers_dict) {
 			string const path = os::external_path(isp_pers_dict);
@@ -2437,6 +2451,10 @@ string const LyXRC::getDescription(LyXRCTags tag)
 		str = _("Specify whether to pass the -T input encoding option to ispell. Enable this if you cannot check the spelling of words containing accented letters. This may not work with all dictionaries.");
 		break;
 
+	case RC_USE_PIXMAP_CACHE:
+		str = _("Enable the pixmap cache that might improve performance on Mac and Windows.");
+		break;
+
 	case RC_USE_SPELL_LIB:
 		break;
 
