@@ -1,22 +1,28 @@
 // -*- C++ -*-
 /**
  * \file SpellBase.h
- * Copyright 2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author unknown
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef SPELL_BASE_H
 #define SPELL_BASE_H
 
-#include "LString.h" // can't forward declare...
+#include "support/docstring.h"
+
+
+namespace lyx {
 
 class BufferParams;
 class WordLangTuple;
 
 /**
- * Base class of all spell checker implementations.
+ * Base class of all spellchecker implementations.
  * The class can be instantiated but will have no functionality.
  */
 class SpellBase {
@@ -24,12 +30,18 @@ public:
 
 	/// the result from checking a single word
 	enum Result  {
-		OK = 1, //< word is correct
-		ROOT, //< root of given word was found
-		COMPOUNDWORD, //< word found through compound formation
-		UNKNOWN, //< word not found
-		MISSED, //< not found, with suggestions
-		IGNORE //< number of other ignored "word"
+		/// word is correct
+		OK = 1,
+		/// root of given word was found
+		ROOT,
+		/// word found through compound formation
+		COMPOUND_WORD,
+		/// word not found
+		UNKNOWN_WORD,
+		/// not found, with suggestions
+		SUGGESTED_WORDS,
+		/// number of other ignored "word"
+		IGNORED_WORD
 	};
 
 	virtual ~SpellBase() {}
@@ -46,12 +58,14 @@ public:
 	/// accept the given word temporarily
 	virtual void accept(WordLangTuple const &);
 
-	/// return the next near miss after a MISSED result
-	virtual string const nextMiss();
+	/// return the next near miss after a SUGGESTED_WORDS result
+	virtual docstring const nextMiss();
 
 	/// give an error message on messy exit
-	virtual string const error();
-
+	virtual docstring const error();
 };
 
+
+} // namespace lyx
+
 #endif // SPELL_BASE_H
