@@ -90,6 +90,7 @@ using support::bformat;
 using support::contains;
 using support::lowercase;
 using support::split;
+using support::subst;
 using support::uppercase;
 
 using cap::cutSelection;
@@ -583,7 +584,7 @@ Color_color Text::backgroundColor() const
 }
 
 
-void Text::breakParagraph(Cursor & cur, bool keep_layout)
+void Text::breakParagraph(Cursor & cur, bool inverse_logic)
 {
 	BOOST_ASSERT(this == cur.text());
 
@@ -608,11 +609,9 @@ void Text::breakParagraph(Cursor & cur, bool keep_layout)
 		cpar.eraseChar(cur.pos(), cur.buffer().params().trackChanges);
 
 	// What should the layout for the new paragraph be?
-	int preserve_layout = 0;
-	if (keep_layout)
-		preserve_layout = 2;
-	else
-		preserve_layout = layout->isEnvironment();
+	bool keep_layout = inverse_logic ? 
+		!layout->isEnvironment() 
+		: layout->isEnvironment();
 
 	// We need to remember this before we break the paragraph, because
 	// that invalidates the layout variable
@@ -622,7 +621,7 @@ void Text::breakParagraph(Cursor & cur, bool keep_layout)
 	bool const isempty = cpar.allowEmpty() && cpar.empty();
 
 	lyx::breakParagraph(cur.buffer().params(), paragraphs(), cpit,
-			 cur.pos(), preserve_layout);
+			 cur.pos(), keep_layout);
 
 	// After this, neither paragraph contains any rows!
 
@@ -1898,6 +1897,9 @@ docstring Text::getPossibleLabel(Cursor & cur) const
 
 	docstring text;
 	docstring par_text = pars_[pit].asString(cur.buffer(), false);
+	string piece;
+	// the return string of math matrices might contain linebreaks
+	par_text = subst(par_text, '\n', '-');
 	for (int i = 0; i < lyxrc.label_init_length; ++i) {
 		if (par_text.empty())
 			break;
