@@ -44,6 +44,7 @@
 #include "Paragraph.h"
 #include "paragraph_funcs.h"
 #include "ParagraphParameters.h"
+#include "toc.h"
 #include "Undo.h"
 #include "VSpace.h"
 #include "ParIterator.h"
@@ -142,18 +143,22 @@ namespace {
 #endif
 			cur.insert(new InsetMathHull(hullSimple));
 			BOOST_ASSERT(old_pos == cur.pos());
-			cur.nextInset()->edit(cur, true);
+			Inset * inset = cur.nextInset();
+			inset->edit(cur, true);
 			// don't do that also for LFUN_MATH_MODE
 			// unless you want end up with always changing
 			// to mathrm when opening an inlined inset --
 			// I really hate "LyXfunc overloading"...
-			if (display)
-				cur.dispatch(FuncRequest(LFUN_MATH_DISPLAY));
+			if (display) {
+				FuncRequest cmdm(LFUN_MATH_DISPLAY);
+				inset->dispatch(cur, cmdm);
+			}
 			// Avoid an unnecessary undo step if cmd.argument
 			// is empty
-			if (!cmd.argument().empty())
-				cur.dispatch(FuncRequest(LFUN_MATH_INSERT,
-							 cmd.argument()));
+			if (!cmd.argument().empty()) {
+				FuncRequest cmdm(LFUN_MATH_INSERT, cmd.argument());
+				inset->dispatch(cur, cmdm);
+			}
 		} else {
 			// create a macro if we see "\\newcommand"
 			// somewhere, and an ordinary formula
@@ -294,7 +299,7 @@ bool Text::isRTL(Buffer const & buffer, Paragraph const & par) const
 
 bool Text::isRTL(Buffer const & buffer, CursorSlice const & sl, bool boundary) const
 {
-	if (!lyxrc.rtl_support && !sl.text())
+	if (!lyxrc.rtl_support || !sl.text())
 		return false;
 
 	int correction = 0;
@@ -668,13 +673,13 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 
 	case LFUN_BREAK_PARAGRAPH:
 		cap::replaceSelection(cur);
-		breakParagraph(cur, 0);
+		breakParagraph(cur, cmd.argument() == "inverse");
 		cur.resetAnchor();
 		break;
 
 	case LFUN_BREAK_PARAGRAPH_KEEP_LAYOUT:
 		cap::replaceSelection(cur);
-		breakParagraph(cur, 1);
+		breakParagraph(cur, true);
 		cur.resetAnchor();
 		break;
 
@@ -685,11 +690,15 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		if (cur.pos() == 0)
 			cur.paragraph().params().labelWidthString(docstring());
 		else
-			breakParagraph(cur, 0);
+			breakParagraph(cur, false);
 		cur.resetAnchor();
 		break;
 	}
 
+	// TODO
+	// With the creation of LFUN_PARAGRAPH_PARAMS, this is now redundant,
+	// as its duties can be performed there. Should it be removed??
+	// FIXME For now, it can just dispatch LFUN_PARAGRAPH_PARAMS...
 	case LFUN_PARAGRAPH_SPACING: {
 		Paragraph & par = cur.paragraph();
 		Spacing::Space cur_spacing = par.params().spacing().getSpace();
@@ -1125,14 +1134,14 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		// true (on).
 
 		if (lyxrc.auto_region_delete && cur.selection()) {
+			pit_type const begpit = cur.selBegin().pit();
+			pit_type const endpit = cur.selEnd().pit();
 			cutSelection(cur, false, false);
-			// When change tracking is set to off, the metrics update
-			// mechanism correctly detects if a full update is needed or not.
-			// This detection fails when a selection spans multiple rows and
-			// change tracking is enabled because the paragraph metrics stays
-			// the same. In this case, we force the full update:
-			// (see http://bugzilla.lyx.org/show_bug.cgi?id=3992)
-			if (cur.buffer().params().trackChanges)
+			// When a selection spans multiple paragraphs, the metrics update
+			// mechanism sometimes fails to detect that a full update is
+			// needed. In this case, we force the full update:
+			// (see http://bugzilla.lyx.org/show_bug.cgi?id=4317)
+			if (isMainText(*cur.bv().buffer()) && begpit != endpit)
 				cur.updateFlags(Update::Force);
 		}
 
@@ -1273,7 +1282,12 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		// reposition the cursor to the caption
 		cur.pit() = cap_pit;
 		cur.pos() = 0;
-		cur.dispatch(FuncRequest(LFUN_CAPTION_INSERT));
+		// FIXME: This Text/Cursor dispatch handling is a mess!
+		// We cannot use Cursor::dispatch here it needs access to up to
+		// date metrics.
+		FuncRequest cmd_caption(LFUN_CAPTION_INSERT);
+		cur.text()->dispatch(cur, cmd_caption);
+		cur.updateFlags(Update::Force);
 		// FIXME: When leaving the Float (or Wrap) inset we should
 		// delete any empty paragraph left above or below the
 		// caption.
@@ -1288,12 +1302,10 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		recordUndo(cur);
 		cur.clearSelection();
 		insertInset(cur, inset);
-		inset->edit(cur, true);
 		// Show the dialog for the nomenclature entry, since the
 		// description entry still needs to be filled in.
 		if (cmd.action == LFUN_NOMENCL_INSERT)
-			InsetCommandMailer("nomenclature",
-				*reinterpret_cast<InsetCommand *>(inset)).showDialog(&cur.bv());
+			inset->edit(cur, true);
 		cur.posRight();
 		break;
 	}
@@ -1364,10 +1376,11 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		// should be used (but it asserts with Bidi enabled)
 		// cf. http://bugzilla.lyx.org/show_bug.cgi?id=4055
 		// cap::replaceSelection(cur);
-		cur.insert(new InsetMathHull(hullSimple));
+		InsetMathHull * inset = new InsetMathHull(hullSimple);
+		cur.insert(inset);
 		checkAndActivateInset(cur, true);
 		BOOST_ASSERT(cur.inMathed());
-		cur.dispatch(cmd);
+		inset->dispatch(cur, cmd);
 		break;
 	}
 
@@ -1531,7 +1544,8 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 			}
 
 			setLayout(cur, tclass.defaultLayoutName());
-			setParagraph(cur, Spacing(), LYX_ALIGN_LAYOUT, docstring(), 0);
+			ParagraphParameters p;
+			setParagraphs(cur, p);
 			insertInset(cur, new InsetFloatList(to_utf8(cmd.argument())));
 			cur.posRight();
 		} else {
@@ -1569,17 +1583,21 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 	case LFUN_PARAGRAPH_PARAMS_APPLY: {
 		// Given data, an encoding of the ParagraphParameters
 		// generated in the Paragraph dialog, this function sets
-		// the current paragraph appropriately.
-		istringstream is(to_utf8(cmd.argument()));
-		Lexer lex(0, 0);
-		lex.setStream(is);
-		ParagraphParameters params;
-		params.read(lex);
-		setParagraph(cur,
-			     params.spacing(),
-			     params.align(),
-			     params.labelWidthString(),
-			     params.noindent());
+		// the current paragraph, or currently selected paragraphs,
+		// appropriately. 
+		// NOTE: This function overrides all existing settings.
+		setParagraphs(cur, cmd.argument());
+		cur.message(_("Paragraph layout set"));
+		break;
+	}
+	
+	case LFUN_PARAGRAPH_PARAMS: {
+		// Given data, an encoding of the ParagraphParameters as we'd
+		// find them in a LyX file, this function modifies the current paragraph, 
+		// or currently selected paragraphs. 
+		// NOTE: This function only modifies, and does not override, existing
+		// settings.
+		setParagraphs(cur, cmd.argument(), true);
 		cur.message(_("Paragraph layout set"));
 		break;
 	}
@@ -1593,6 +1611,32 @@ void Text::dispatch(Cursor & cur, FuncRequest & cmd)
 		}
 		break;
 
+	case LFUN_OUTLINE_UP:
+		toc::outline(toc::Up, cur);
+		setCursor(cur, cur.pit(), 0);
+		updateLabels(cur.buffer());
+		needsUpdate = true;
+		break;
+
+	case LFUN_OUTLINE_DOWN:
+		toc::outline(toc::Down, cur);
+		setCursor(cur, cur.pit(), 0);
+		updateLabels(cur.buffer());
+		needsUpdate = true;
+		break;
+
+	case LFUN_OUTLINE_IN:
+		toc::outline(toc::In, cur);
+		updateLabels(cur.buffer());
+		needsUpdate = true;
+		break;
+
+	case LFUN_OUTLINE_OUT:
+		toc::outline(toc::Out, cur);
+		updateLabels(cur.buffer());
+		needsUpdate = true;
+		break;
+
 	default:
 		LYXERR(Debug::ACTION)
 			<< BOOST_CURRENT_FUNCTION
@@ -1907,6 +1951,13 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 		enable = true;
 		break;
 
+	case LFUN_OUTLINE_UP:
+	case LFUN_OUTLINE_DOWN:
+	case LFUN_OUTLINE_IN:
+	case LFUN_OUTLINE_OUT:
+		enable = (cur.paragraph().layout()->toclevel != Layout::NOT_IN_TOC);
+		break;
+
 	case LFUN_WORD_DELETE_FORWARD:
 	case LFUN_WORD_DELETE_BACKWARD:
 	case LFUN_LINE_DELETE:
@@ -1997,6 +2048,7 @@ bool Text::getStatus(Cursor & cur, FuncRequest const & cmd,
 	case LFUN_ACCENT_OGONEK:
 	case LFUN_THESAURUS_ENTRY:
 	case LFUN_PARAGRAPH_PARAMS_APPLY:
+	case LFUN_PARAGRAPH_PARAMS:
 	case LFUN_ESCAPE:
 	case LFUN_BUFFER_END:
 	case LFUN_BUFFER_BEGIN:
