@@ -12,7 +12,7 @@
 #ifndef CONTROLERRORLIST_H
 #define CONTROLERRORLIST_H
 
-#include "errorlist.h"
+#include "ErrorList.h"
 #include "Dialog.h"
 
 namespace lyx {
@@ -38,17 +38,12 @@ public:
 	/// return the parent document name
 	std::string const & name();
 	///
-	ErrorList const & errorList();
-	/// return true when the error list has been updated, but 
-	/// \c errorlist() has not been called.
-	bool hasUnreadList() const;
+	ErrorList const & errorList() const;
 private:
 	///
-	ErrorList errorlist_;
+	std::string error_type_;
 	///
 	std::string name_;
-	/// 
-	bool unreadlist_;
 };
 
 } // namespace frontend
