@@ -13,11 +13,12 @@
 #define CONTROLPARAGRAPH_H
 
 #include "Dialog.h"
-#include "layout.h" // for LyXAlignment
+#include "Layout.h" // for LyXAlignment
+
+namespace lyx {
 
 class ParagraphParameters;
 
-namespace lyx {
 namespace frontend {
 
 class ControlParagraph : public Dialog::Controller {
@@ -37,8 +38,12 @@ public:
 	///
 	ParagraphParameters const & params() const;
 	///
+	bool const haveMulitParSelection();
+	///
 	bool inInset() const;
 	///
+	bool canIndent() const;
+	///
 	LyXAlignment alignPossible() const;
 	///
 	LyXAlignment alignDefault() const;
