@@ -14,20 +14,23 @@
 #ifndef KEY_STATE_H
 #define KEY_STATE_H
 
+namespace lyx {
+
 /// modifier key states
 namespace key_modifier {
-	enum state {
-		none	= 0, //< no modifiers held
-		ctrl	= 1, //< control button held
-		alt	= 2, //< alt/meta key held
-		shift	= 4  //< shift key held
-	};
+
+enum state {
+	none  = 0, //< no modifiers held
+	ctrl  = 1, //< control button held
+	alt   = 2, //< alt/meta key held
+	shift = 4  //< shift key held
+};
 
 
 inline state operator|(state const & s1, state const & s2)
 {
-	int const i1(static_cast<int>(s1));
-	int const i2(static_cast<int>(s2));
+	int const i1 = static_cast<int>(s1);
+	int const i2 = static_cast<int>(s2);
 	return static_cast<state>(i1 | i2);
 }
 
@@ -39,4 +42,7 @@ inline void operator|=(state & s1, state s2)
 
 } // namespace key_modifier
 
+
+} // namespace lyx
+
 #endif // KEY_STATE_H
