@@ -16,15 +16,19 @@
 
 #include "frontends/Selection.h"
 
+#include <QObject>
+
 namespace lyx {
 namespace frontend {
 
 /**
  * The Qt4 version of the Selection.
  */
-class GuiSelection : public Selection
+class GuiSelection : public QObject, public Selection
 {
+	Q_OBJECT
 public:
+	GuiSelection();
 	virtual ~GuiSelection() {}
 
 	/** Selection overloaded methods
@@ -35,6 +39,13 @@ public:
 	void put(docstring const & str);
 	bool empty() const;
 	//@}
+
+private Q_SLOTS:
+	void on_dataChanged();
+
+private:
+	bool text_selection_empty_;
+	bool const selection_supported_;
 };
 
 } // namespace frontend
