@@ -208,11 +208,20 @@ void IconPalette::hideEvent(QHideEvent * event )
 void IconPalette::updateParent()
 {
 	bool enable = false;
+
+	// FIXME: so this is commented out for speed considerations
+	// true fix is to repair the updating mechanism of the toolbar
+#if 0
 	for (int i = 0; i < actions_.size(); ++i)
 		if (actions_.at(i)->isEnabled()) {
 			enable = true;
 			break;
 		}
+#else
+	// we check only the first action to enable/disable the panel
+	if (!actions_.isEmpty())
+		enable = actions_.at(0)->isEnabled();
+#endif
 
 	parentWidget()->setEnabled(enable);
 }
@@ -257,11 +266,19 @@ void ButtonMenu::add(QAction * action)
 void ButtonMenu::updateParent()
 {
 	bool enable = false;
+	// FIXME: so this is commented out for speed considerations
+	// true fix is to repair the updating mechanism of the toolbar
+#if 0
 	for (int i = 0; i < actions_.size(); ++i)
 		if (actions_.at(i)->isEnabled()) {
 			enable = true;
 			break;
 		}
+#else
+	// we check only the first action to enable/disable the menu
+	if (!actions_.isEmpty())
+		enable = actions_.at(0)->isEnabled();
+#endif
 
 	parentWidget()->setEnabled(enable);
 }
