@@ -15,6 +15,7 @@
 #include "Qt2BC.h"
 #include "qt_helpers.h"
 #include "GuiApplication.h"
+#include "GuiFontLoader.h"
 
 #include "ConverterCache.h"
 #include "Session.h"
@@ -38,6 +39,7 @@
 #include <QColorDialog>
 #include <QFontDatabase>
 #include <QLineEdit>
+#include <QPixmapCache>
 #include <QPushButton>
 #include <QSpinBox>
 #include <QString>
@@ -454,6 +456,11 @@ void PrefScreenFonts::apply(LyXRC & rc) const
 		|| rc.sans_font_name != oldrc.sans_font_name
 		|| rc.typewriter_font_name != oldrc.typewriter_font_name
 		|| rc.zoom != oldrc.zoom || rc.dpi != oldrc.dpi) {
+		// The global QPixmapCache is used in GuiPainter to cache text
+		// painting so we must reset it in case any of the above
+		// parameter is changed.
+		QPixmapCache::clear();
+		guiApp->fontLoader().update();
 		form_->controller().updateScreenFonts();
 	}
 }
@@ -1806,6 +1813,8 @@ PrefUserInterface::PrefUserInterface(QPrefs * form, QWidget * parent)
 		this, SIGNAL(changed()));
 	connect(lastfilesSB, SIGNAL(valueChanged(int)),
 		this, SIGNAL(changed()));
+	connect(pixmapCacheCB, SIGNAL(toggled(bool)),
+		this, SIGNAL(changed()));
 	lastfilesSB->setMaximum(maxlastfiles);
 }
 
@@ -1828,6 +1837,7 @@ void PrefUserInterface::apply(LyXRC & rc) const
 	rc.autosave = autoSaveSB->value() * 60;
 	rc.make_backup = autoSaveCB->isChecked();
 	rc.num_lastfiles = lastfilesSB->value();
+	rc.use_pixmap_cache = pixmapCacheCB->isChecked();
 }
 
 
@@ -1852,6 +1862,10 @@ void PrefUserInterface::update(LyXRC const & rc)
 	autoSaveSB->setValue(mins);
 	autoSaveCB->setChecked(rc.make_backup);
 	lastfilesSB->setValue(rc.num_lastfiles);
+	pixmapCacheCB->setChecked(rc.use_pixmap_cache);
+#if (QT_VERSION < 0x040200) || defined(Q_WS_X11)
+	pixmapCacheGB->setEnabled(false);
+#endif
 }
 
 
