@@ -568,8 +568,16 @@ goto_char_backwards:
 			// notify left insets and give them chance to set update flags
 			lyx::notifyCursorLeaves(cur.beforeDispatchCursor(), cur);
 			cur.fixIfBroken();
-		}	else
-			cur.undispatched();
+			break;
+		}
+		
+		if (cur.fixIfBroken())
+			// FIXME: Something bad happened. We pass the corrected Cursor
+			// instead of letting things go worse.
+			break;
+
+		// We did not manage to move the cursor.
+		cur.undispatched();
 		break;
 	}
 
@@ -995,6 +1003,12 @@ goto_char_backwards:
 			cur.undispatched();
 		break;
 	}
+	case LFUN_INSET_DISSOLVE:
+		if (!asHullInset()) {
+			recordUndoInset(cur, Undo::ATOMIC);
+			cur.pullArg();
+		}
+		break;
 
 	default:
 		InsetMath::doDispatch(cur, cmd);
@@ -1104,6 +1118,10 @@ bool InsetMathNest::getStatus(Cursor & cur, FuncRequest const & cmd,
 		flag.enabled(false);
 		break;
 
+	case LFUN_INSET_DISSOLVE:
+		flag.enabled(!asHullInset());
+		break;
+
 	default:
 		ret = false;
 		break;
@@ -1153,32 +1171,30 @@ void InsetMathNest::lfunMousePress(Cursor & cur, FuncRequest & cmd)
 {
 	//lyxerr << "## lfunMousePress: buttons: " << cmd.button() << endl;
 	BufferView & bv = cur.bv();
-	// FIXME: the following should be replaced by a better fix
-	// that is already used for plain text (Text3.cpp).
-	cap::saveSelection(bv.cursor());
+	bv.mouseSetCursor(cur);
 	if (cmd.button() == mouse_button::button1) {
 		//lyxerr << "## lfunMousePress: setting cursor to: " << cur << endl;
-		bv.mouseSetCursor(cur);
 		// Update the cursor update flags as needed:
 		//
-		// Update::Decoration: tells to update the decoration (visual box
-		//                     corners that define the inset)/
-		// Update::FitCursor: adjust the screen to the cursor position if
-		//                    needed
+		// Update::Decoration: tells to update the decoration
+		//                     (visual box corners that define
+		//                     the inset)/
+		// Update::FitCursor: adjust the screen to the cursor
+		//                    position if needed
 		// cur.result().update(): don't overwrite previously set flags.
-		cur.updateFlags(Update::Decoration | Update::FitCursor | cur.result().update());
+		cur.updateFlags(Update::Decoration | Update::FitCursor 
+				| cur.result().update());
 	} else if (cmd.button() == mouse_button::button2) {
-		MathData ar;
 		if (cap::selection()) {
 			// See comment in Text::dispatch why we do this
 			cap::copySelectionToStack();
 			cmd = FuncRequest(LFUN_PASTE, "0");
-			doDispatch(cur, cmd);
-		} else
+			doDispatch(bv.cursor(), cmd);
+		} else {
+			MathData ar;
 			asArray(theSelection().get(), ar);
-
-		cur.insert(ar);
-		bv.mouseSetCursor(cur);
+			bv.cursor().insert(ar);
+		}
 	}
 }
 
