@@ -150,7 +150,7 @@ bool addCol(InsetMathGrid & grid, InsetMathGrid::col_type & cellcol)
 	++cellcol;
 	if (cellcol == grid.ncols()) {
 		//lyxerr << "adding column " << cellcol << endl;
-		grid.addCol(cellcol - 1);
+		grid.addCol(cellcol);
 		if (cellcol == grid.ncols()) {
 			// We can't add a column to this grid, so let's
 			// append the content of this cell to the previous
@@ -463,8 +463,11 @@ bool Parser::good() const
 
 char_type Parser::getChar()
 {
-	if (!good())
+	if (!good()) {
 		error("The input stream is not well...");
+		putback();
+		return 0;
+	}
 	return tokens_[pos_++].character();
 }
 
@@ -1017,12 +1020,14 @@ void Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		else if (t.cs() == "\\") {
 			if (flags & FLAG_ALIGN)
 				return;
-			bool added;
+			bool added = false;
 			if (nextToken().asInput() == "*") {
 				getToken();
 				added = addRow(grid, cellrow, docstring(), false);
-			} else
+			} else if (good())
 				added = addRow(grid, cellrow, getArg('[', ']'));
+			else
+				error("missing token after \\\\");
 			if (added) {
 				cellcol = 0;
 				if (grid.asHullInset())
