@@ -12,6 +12,9 @@
 #ifndef LYX_FILETOOL_H
 #define LYX_FILETOOL_H
 
+#include "support/docstring.h"
+#include "support/FileName.h"
+
 #include <vector>
 #include <utility>
 #include <string>
@@ -20,13 +23,13 @@ namespace lyx {
 namespace support {
 
 /// remove directory and all contents, returns true on success
-bool destroyDir(std::string const & tmpdir);
+bool destroyDir(FileName const & tmpdir);
 
 /// Creates the per buffer temporary directory
 std::string const createBufferTmpDir();
 
 /// Creates directory. Returns true on success
-bool createDirectory(std::string const & name, int permissions);
+bool createDirectory(FileName const & name, int permissions);
 
 /** Creates the global LyX temp dir.
   \p deflt can be an existing directory name. In this case a new directory
@@ -34,8 +37,10 @@ bool createDirectory(std::string const & name, int permissions);
   created and used as the temporary directory.
   \return the tmp dir name or string() if something went wrong.
  */
-std::string const createLyXTmpDir(std::string const & deflt);
+FileName const createLyXTmpDir(FileName const & deflt);
 
+#if 0
+// FIXME unused. Should this be deleted or resurrected?
 /** Find file by searching several directories.
   Uses a string of paths separated by ";"s to find a file to open.
     Can't cope with pathnames with a ';' in them. Returns full path to file.
@@ -43,38 +48,54 @@ std::string const createLyXTmpDir(std::string const & deflt);
     If path entry begins with $$User/, use user_lyxdir.
     Example: "$$User/doc;$$LyX/doc".
 */
-std::string const FileOpenSearch(std::string const & path, std::string const & name,
-		       std::string const & ext = std::string());
+FileName const fileOpenSearch(std::string const & path,
+				 std::string const & name,
+				 std::string const & ext = std::string());
+#endif
+
+/// How to search files
+enum search_mode {
+	// The file must exist (return an empty file name otherwise)
+	standard_mode,
+	/// Only do file name expansion, return the complete name even if
+	/// the file does not exist
+	allow_unreadable
+};
 
 /** Returns the real name of file name in directory path, with optional
   extension ext.
   The file is searched in the given path (unless it is an absolute
   file name), first directly, and then with extension .ext (if given).
   */
-std::string const FileSearch(std::string const & path, std::string const & name,
-		  std::string const & ext = std::string());
+FileName const fileSearch(std::string const & path,
+			     std::string const & name,
+			     std::string const & ext = std::string(),
+			     search_mode mode = standard_mode);
 
 /// Returns a vector of all files in directory dir having extension ext.
-std::vector<std::string> const DirList(std::string const & dir,
-				  std::string const & ext = std::string());
+std::vector<FileName> const dirList(FileName const & dir,
+				       std::string const & ext = std::string());
 
 /** Is directory read only?
   returns
     true: dir writeable
     false: not writeable
 */
-bool IsDirWriteable (std::string const & path);
+bool isDirWriteable(FileName const & path);
 
 /** Is a file readable ?
   Returns true if the file `path' is readable.
  */
-bool IsFileReadable (std::string const & path);
+bool isFileReadable(FileName const & path);
 
 ///
-bool IsLyXFilename(std::string const & filename);
+bool isLyXFilename(std::string const & filename);
 
 ///
-bool IsSGMLFilename(std::string const & filename);
+bool isSGMLFilename(std::string const & filename);
+
+///
+bool isValidLaTeXFilename(std::string const & filename);
 
 /** Returns the path of a library data file.
     Search the file name.ext in the subdirectory dir of
@@ -83,15 +104,17 @@ bool IsSGMLFilename(std::string const & filename);
       -# system_lyxdir
     The third parameter `ext' is optional.
 */
-std::string const LibFileSearch(std::string const & dir, std::string const & name,
-		     std::string const & ext = std::string());
+FileName const libFileSearch(std::string const & dir,
+				std::string const & name,
+				std::string const & ext = std::string());
 
-/** Same as LibFileSearch(), but tries first to find an
+/** Same as libFileSearch(), but tries first to find an
   internationalized version of the file by prepending $LANG_ to the
   name
   */
-std::string const
-i18nLibFileSearch(std::string const & dir, std::string const & name,
+FileName const
+i18nLibFileSearch(std::string const & dir,
+		  std::string const & name,
 		  std::string const & ext = std::string());
 
 /// How to quote a filename
@@ -101,7 +124,7 @@ enum quote_style {
 	quote_shell,
 	/** Quote for python. Use this if you want to store a filename in a
 	    python script. Example: \code
-	    os << "infile = " << QuoteName(filename) << '\\n';
+	    os << "infile = " << quoteName(filename) << '\\n';
 	    \endcode This uses double quotes, so that you can also use this
 	    to quote filenames as part of a string if the string is quoted
 	    with single quotes. */
@@ -114,7 +137,7 @@ enum quote_style {
  *  command will still fail, but the error message will make some sort of
  *  sense ;-)
  */
-std::string const LibScriptSearch(std::string const & command,
+std::string const libScriptSearch(std::string const & command,
 		quote_style style = quote_shell);
 
 enum latex_path_extension {
@@ -151,36 +174,47 @@ std::string const latex_path(std::string const & path,
 		latex_path_dots dots = LEAVE_DOTS);
 
 /// Substitutes active latex characters with underscores in filename
-std::string const MakeLatexName(std::string const & file);
+std::string const makeLatexName(std::string const & file);
 
 /** Put the name in quotes suitable for the current shell or python,
     depending on \p style. */
-std::string const QuoteName(std::string const & file, quote_style style = quote_shell);
+std::string const quoteName(std::string const & file, quote_style style = quote_shell);
 
 /// Add a filename to a path. Any path from filename is stripped first.
-std::string const AddName(std::string const & path, std::string const & fname);
+std::string const addName(std::string const & path, std::string const & fname);
 
 /// Append sub-directory(ies) to path in an intelligent way
-std::string const AddPath(std::string const & path, std::string const & path2);
+std::string const addPath(std::string const & path, std::string const & path2);
 
 /** Change extension of oldname to extension.
  If oldname does not have an extension, it is appended.
  If the extension is empty, any extension is removed from the name.
  */
 std::string const
-ChangeExtension(std::string const & oldname, std::string const & extension);
+changeExtension(std::string const & oldname, std::string const & extension);
+
+/// Remove the extension from \p name
+std::string const removeExtension(std::string const & name);
+
+/** Add the extension \p ext to \p name.
+ Use this instead of changeExtension if you know that \p name is without
+ extension, because changeExtension would wrongly interpret \p name if it
+ contains a dot.
+ */
+std::string const
+addExtension(std::string const & name, std::string const & extension);
 
 /// Return the extension of the file (not including the .)
-std::string const GetExtension(std::string const & name);
+std::string const getExtension(std::string const & name);
 
 /** Guess the file format name (as in Format::name()) from contents.
  Normally you don't want to use this directly, but rather
  Formats::getFormatFromFile().
  */
-std::string const getFormatFromContents(std::string const & name);
+std::string const getFormatFromContents(FileName const & name);
 
 /// check for zipped file
-bool zippedFile(std::string const & name);
+bool zippedFile(FileName const & name);
 
 /** \return the name that LyX will give to the unzipped file \p zipped_file
   if the second argument of unzipFile() is empty.
@@ -192,27 +226,27 @@ std::string const unzippedFileName(std::string const & zipped_file);
   empty, and unzippedFileName(\p zipped_file) otherwise.
   Will overwrite an already existing unzipped file without warning.
  */
-std::string const unzipFile(std::string const & zipped_file,
-                            std::string const & unzipped_file = std::string());
+FileName const unzipFile(FileName const & zipped_file,
+			 std::string const & unzipped_file = std::string());
 
 /// Returns true is path is absolute
-bool AbsolutePath(std::string const & path);
+bool absolutePath(std::string const & path);
 
 /// Create absolute path. If impossible, don't do anything
-std::string const ExpandPath(std::string const & path);
+std::string const expandPath(std::string const & path);
 
 /** Convert relative path into absolute path based on a basepath.
   If relpath is absolute, just use that.
   If basepath doesn't exist use CWD.
   */
-std::string const MakeAbsPath(std::string const & RelPath = std::string(),
-			 std::string const & BasePath = std::string());
+FileName const makeAbsPath(std::string const & RelPath = std::string(),
+			      std::string const & BasePath = std::string());
 
 /** Creates a nice compact path for displaying. The parameter
   threshold, if given, specifies the maximal length of the path.
   */
-std::string const
-MakeDisplayPath(std::string const & path, unsigned int threshold = 1000);
+docstring const
+makeDisplayPath(std::string const & path, unsigned int threshold = 1000);
 
 /** Makes relative path out of absolute path.
   If it is deeper than basepath,
@@ -221,43 +255,51 @@ MakeDisplayPath(std::string const & path, unsigned int threshold = 1000);
   different, then the absolute path will be used as relative path
   WARNING: the absolute path and base path must really be absolute paths!!!
   */
-std::string const
-MakeRelPath(std::string const & abspath, std::string const & basepath);
+docstring const
+makeRelPath(docstring const & abspath, docstring const & basepath);
 
 /// Strip filename from path name
-std::string const OnlyPath(std::string const & fname);
+std::string const onlyPath(std::string const & fname);
 
 /** Normalize a path. Constracts path/../path
  *  Also converts paths like /foo//bar ==> /foo/bar
  */
-std::string const NormalizePath(std::string const & path);
+std::string const normalizePath(std::string const & path);
 
 /// Strips path from filename
-std::string const OnlyFilename(std::string const & fname);
+std::string const onlyFilename(std::string const & fname);
 
 /// Get the contents of a file as a huge std::string
-std::string const GetFileContents(std::string const & fname);
+std::string const getFileContents(FileName const & fname);
 
 /** Check and Replace Environmentvariables ${NAME} in Path.
     Replaces all occurences of these, if they are found in the
     environment.
     Variables are defined by Var := '${' [a-zA-Z_][a-zA-Z_0-9]* '}'
 */
-std::string const ReplaceEnvironmentPath(std::string const & path);
+std::string const replaceEnvironmentPath(std::string const & path);
 
-/* Set \c link to the path \c file points to as a symbolic link.
-   If \c resolve is true, then \c link is an absolute path
-   Returns true if successful */
-bool LyXReadLink(std::string const & file, std::string & link, bool resolve = false);
+/** Set \c link to the path \c file points to as a symbolic link.
+    \return true if successful.
+ */
+bool readLink(FileName const & file, FileName & link);
 
-/// Uses kpsewhich to find tex files
-std::string const findtexfile(std::string const & fil, std::string const & format);
+/**
+ * Search a TeX file in all locations the latex compiler would search it,
+ * with the help of kpsewhich.
+ * The current working directory must be set correctly, so that relative
+ * names work.
+ * \param fil The filename to search
+ * \param format The file format as used by kpsewhich, e.g. "bib", "bst" etc.
+ */
+FileName const findtexfile(std::string const & fil,
+			      std::string const & format);
 
 /// remove the autosave-file and give a Message if it can't be done
 void removeAutosaveFile(std::string const & filename);
 
 /// read the BoundingBox entry from a ps/eps/pdf-file
-std::string const readBB_from_PSFile(std::string const & file);
+std::string const readBB_from_PSFile(FileName const & file);
 
 /** \param file1, file2 the two files to be compared. Must have absolute paths.
  *  \returns 1 if \c file1 has a more recent timestamp than \c file2,
@@ -266,11 +308,11 @@ std::string const readBB_from_PSFile(std::string const & file);
  *  If one of the files does not exist, the return value indicates the file
  *  which does exist. Eg, if \c file1 exists but \c file2 does not, return 1.
  */
-int compare_timestamps(std::string const & file1, std::string const & file2);
+int compare_timestamps(FileName const & file1, FileName const & file2);
 
 typedef std::pair<int, std::string> cmd_ret;
 
-cmd_ret const RunCommand(std::string const & cmd);
+cmd_ret const runCommand(std::string const & cmd);
 
 } // namespace support
 } // namespace lyx
