@@ -32,24 +32,6 @@ using std::string;
 
 using lyx::support::contains;
 
-#ifdef X_DISPLAY_MISSING
-#include "support/filetools.h"
-#include "support/Package.h"
-#include "support/Path.h"
-using lyx::support::addName;
-using lyx::support::addPath;
-using lyx::support::package;
-
-// API definition for manually calling font functions on Windows 2000 and later
-typedef int (WINAPI *FONTAPI)(LPCSTR, DWORD, PVOID);
-#define FR_PRIVATE     0x10
-
-// Names of TrueType fonts to load
-string const win_fonts_truetype[] = {"cmex10", "cmmi10", "cmr10", "cmsy10",
-	"eufm10", "msam10", "msbm10", "wasy10", "esint10"};
-const int num_fonts_truetype = sizeof(win_fonts_truetype) / sizeof(*win_fonts_truetype);
-#endif
-
 
 namespace lyx {
 namespace support {
@@ -145,45 +127,11 @@ string convert_path_list(string const & p, PathStyle const & target)
 
 void os::init(int, char *[])
 {
-	// Copy cygwin environment variables to the Windows environment
-	// if they're not already there.
+	// Make sure that the TEMP variable is set
+	// and sync the Windows environment.
 
-	char **envp = environ;
-	char curval[2];
-	string var;
-	string val;
-	bool temp_seen = false;
-
-	while (envp && *envp) {
-		val = split(*envp++, var, '=');
-
-		if (var == "TEMP")
-			temp_seen = true;
-
-		if (GetEnvironmentVariable(var.c_str(), curval, 2) == 0
-				&& GetLastError() == ERROR_ENVVAR_NOT_FOUND) {
-			/* Convert to Windows style where necessary */
-			if (var == "PATH" || var == "LD_LIBRARY_PATH") {
-				string const winpathlist =
-				    convert_path_list(val, PathStyle(windows));
-				if (!winpathlist.empty()) {
-					SetEnvironmentVariable(var.c_str(),
-						winpathlist.c_str());
-				}
-			} else if (var == "HOME" || var == "TMPDIR" ||
-					var == "TMP" || var == "TEMP") {
-				string const winpath =
-					convert_path(val, PathStyle(windows));
-				SetEnvironmentVariable(var.c_str(), winpath.c_str());
-			} else {
-				SetEnvironmentVariable(var.c_str(), val.c_str());
-			}
-		}
-	}
-	if (!temp_seen) {
-		string const winpath = convert_path("/tmp", PathStyle(windows));
-		SetEnvironmentVariable("TEMP", winpath.c_str());
-	}
+	setenv("TEMP", "/tmp", false);
+	cygwin_internal(CW_SYNC_WINENV);
 }
 
 
@@ -328,59 +276,6 @@ bool autoOpenFile(string const & filename, auto_open_mode const mode)
 		win_path.c_str(), NULL, NULL, 1)) > 32;
 }
 
-
-void addFontResources()
-{
-#ifdef X_DISPLAY_MISSING
-	// Windows only: Add BaKoMa TrueType font resources
-	string const fonts_dir = addPath(package().system_support().absFilename(), "fonts");
-
-	HMODULE hDLL = LoadLibrary("gdi32");
-	FONTAPI pAddFontResourceEx =
-		(FONTAPI) GetProcAddress(hDLL, "AddFontResourceExA");
-
-	for (int i = 0 ; i < num_fonts_truetype ; ++i) {
-		string const font_current = to_local8bit(from_utf8(convert_path(
-			addName(fonts_dir, win_fonts_truetype[i] + ".ttf"),
-			PathStyle(windows))));
-		if (pAddFontResourceEx) {
-			// Windows 2000 and later: Use AddFontResourceEx
-			pAddFontResourceEx(font_current.c_str(), FR_PRIVATE, 0);
-		} else {
-			// Older Windows versions: Use AddFontResource
-			AddFontResource(font_current.c_str());
-		}
-	}
-	FreeLibrary(hDLL);
-#endif
-}
-
-
-void restoreFontResources()
-{
-#ifdef X_DISPLAY_MISSING
-	// Windows only: Remove BaKoMa TrueType font resources
-	string const fonts_dir = addPath(package().system_support().absFilename(), "fonts");
-
-	HMODULE hDLL = LoadLibrary("gdi32");
-	FONTAPI pRemoveFontResourceEx = (FONTAPI) GetProcAddress(hDLL, "RemoveFontResourceExA");
-
-	for(int i = 0 ; i < num_fonts_truetype ; ++i) {
-		string const font_current = to_local8bit(from_utf8(convert_path(
-			addName(fonts_dir, win_fonts_truetype[i] + ".ttf"),
-			PathStyle(windows))));
-		if (pRemoveFontResourceEx) {
-			// Windows 2000 and later: Use RemoveFontResourceEx
-			pRemoveFontResourceEx(font_current.c_str(), FR_PRIVATE, 0);
-		} else {
-			// Older Windows versions: Use RemoveFontResource
-			RemoveFontResource(font_current.c_str());
-		}
-	}
-	FreeLibrary(hDLL);
-#endif
-}
-
 } // namespace os
 } // namespace support
 } // namespace lyx
