@@ -19,8 +19,6 @@
 #include "support/lstrings.h"
 #include "support/filetools.h"
 #include "support/ExceptionMessage.h"
-#include "support/Package.h"
-#include "support/Path.h"
 
 #include "debug.h"
 #include "gettext.h"
@@ -70,18 +68,6 @@ using std::string;
 
 using lyx::support::runCommand;
 using lyx::support::split;
-using lyx::support::addName;
-using lyx::support::addPath;
-using lyx::support::package;
-
-// API definition for manually calling font functions on Windows 2000 and later
-typedef int (WINAPI *FONTAPI)(LPCSTR, DWORD, PVOID);
-#define FR_PRIVATE     0x10
-
-// Names of TrueType fonts to load
-string const win_fonts_truetype[] = {"cmex10", "cmmi10", "cmr10", "cmsy10",
-	"eufm10", "msam10", "msbm10", "wasy10", "esint10"};
-const int num_fonts_truetype = sizeof(win_fonts_truetype) / sizeof(*win_fonts_truetype);
 
 
 namespace lyx {
@@ -407,54 +393,6 @@ bool autoOpenFile(string const & filename, auto_open_mode const mode)
 		to_local8bit(from_utf8(filename)).c_str(), NULL, NULL, 1)) > 32;
 }
 
-
-void addFontResources()
-{
-	// Windows only: Add BaKoMa TrueType font resources
-	string const fonts_dir = addPath(package().system_support().absFilename(), "fonts");
-
-	HMODULE hDLL = LoadLibrary("gdi32");
-	FONTAPI pAddFontResourceEx = (FONTAPI) GetProcAddress(hDLL, "AddFontResourceExA");
-
-	for (int i = 0 ; i < num_fonts_truetype ; ++i) {
-		string const font_current =
-			addName(fonts_dir, win_fonts_truetype[i] + ".ttf");
-		if (pAddFontResourceEx) {
-			// Windows 2000 and later: Use AddFontResourceEx for private font
-			pAddFontResourceEx(to_local8bit(from_utf8(external_path(font_current))).c_str(), FR_PRIVATE, 0);
-		} else {
-			// Older Windows versions: Use AddFontResource
-			AddFontResource(to_local8bit(from_utf8(external_path(font_current))).c_str());
-		}
-	}
-
-	FreeLibrary(hDLL);
-}
-
-
-void restoreFontResources()
-{
-	// Windows only: Remove BaKoMa TrueType font resources
-	string const fonts_dir = addPath(package().system_support().absFilename(), "fonts");
-
-	HMODULE hDLL = LoadLibrary("gdi32");
-	FONTAPI pRemoveFontResourceEx = (FONTAPI) GetProcAddress(hDLL, "RemoveFontResourceExA");
-
-	for(int i = 0 ; i < num_fonts_truetype ; ++i) {
-		string const font_current =
-			addName(fonts_dir, win_fonts_truetype[i] + ".ttf");
-		if (pRemoveFontResourceEx) {
-			// Windows 2000 and later: Use RemoveFontResourceEx for private font
-			pRemoveFontResourceEx(to_local8bit(from_utf8(external_path(font_current))).c_str(), FR_PRIVATE, 0);
-		} else {
-			// Older Windows versions: Use RemoveFontResource
-			RemoveFontResource(to_local8bit(from_utf8(external_path(font_current))).c_str());
-		}
-	}
-
-	FreeLibrary(hDLL);
-}
-
 } // namespace os
 } // namespace support
 } // namespace lyx
