@@ -4,6 +4,7 @@
  * Licence details can be found in the file COPYING.
  *
  * \author Andr Pnitz
+ * \author Uwe Sthr
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -17,6 +18,7 @@
 #include "Layout.h"
 #include "Lexer.h"
 #include "TextClass.h"
+#include "support/convert.h"
 #include "support/filetools.h"
 #include "support/lstrings.h"
 
@@ -37,42 +39,72 @@ using std::string;
 using std::vector;
 using std::cerr;
 using std::endl;
+using std::find;
 
 using support::FileName;
 using support::libFileSearch;
+using support::isStrDbl;
 
 // special columntypes
 extern std::map<char, int> special_columns;
 
 std::map<string, vector<string> > used_packages;
 
+// needed to handle encodings with babel
+bool one_language = true;
+
+// to avoid that the babel options overwrite the documentclass options
+bool documentclass_language;
+
 namespace {
 
-const char * const known_languages[] = { "austrian", "babel", "bahasa",
-"basque", "breton", "british", "bulgarian", "catalan", "croatian", "czech",
-"danish", "dutch", "english", "esperanto", "estonian", "finnish",
-"francais", "french", "frenchb", "frenchle", "frenchpro",
-"galician", "german", "germanb", "greek", "hebcal", "hebfont",
-"hebrew", "hebrew_newcode", "hebrew_oldcode", "hebrew_p", "hyphen",
+const char * const known_languages[] = { "afrikaans", "american", "austrian",
+"babel", "bahasa", "basque", "belarusian", "brazil", "breton", "british",
+"bulgarian", "catalan", "croatian", "czech", "danish", "dutch", "english",
+"esperanto", "estonian", "finnish", "francais", "french", "frenchb",
+"frenchle", "frenchpro", "galician", "german", "germanb", "greek", "hebcal",
+"hebfont", "hebrew", "hebrew_newcode", "hebrew_oldcode", "hebrew_p", "hyphen",
 "icelandic", "irish", "italian", "latin", "lgrcmr", "lgrcmro", "lgrcmss",
-"lgrcmtt", "lgrenc", "lgrlcmss", "lgrlcmtt", "lheclas", "lhecmr",
-"lhecmss", "lhecmtt", "lhecrml", "lheenc", "lhefr", "lheredis", "lheshold",
-"lheshscr", "lheshstk", "lsorbian", "magyar", "naustrian", "ngermanb",
-"ngerman", "norsk", "polish", "portuges", "rlbabel", "romanian",
-"russianb", "samin", "scottish", "serbian", "slovak", "slovene", "spanish",
-"swedish", "turkish", "ukraineb", "usorbian", "welsh", 0};
+"lgrcmtt", "lgrenc", "lgrlcmss", "lgrlcmtt", "lheclas", "lhecmr", "lhecmss",
+"lhecmtt", "lhecrml", "lheenc", "lhefr", "lheredis", "lheshold", "lheshscr",
+"lheshstk", "lsorbian", "magyar", "naustrian", "ngermanb", "ngerman", "norsk",
+"nynorsk", "polish", "portuges", "rlbabel", "romanian",	"russian", "russianb",
+"samin", "scottish", "serbian", "slovak", "slovene", "spanish", "swedish",
+"thai", "turkish", "ukraineb", "ukrainian", "usorbian", "welsh", 0};
 
 const char * const known_french_languages[] = {"french", "frenchb", "francais",
-					       "frenchle", "frenchpro", 0};
+						"frenchle", "frenchpro", 0};
+const char * const known_german_languages[] = {"german", "germanb", 0};
+const char * const known_ngerman_languages[] = {"ngerman", "ngermanb", 0};
+const char * const known_russian_languages[] = {"russian", "russianb", 0};
+const char * const known_ukrainian_languages[] = {"ukrainian", "ukraineb", 0};
+
 char const * const known_fontsizes[] = { "10pt", "11pt", "12pt", 0 };
 
+const char * const known_roman_fonts[] = { "ae", "bookman", "charter",
+"cmr", "fourier", "lmodern", "mathpazo", "mathptmx", "newcent", 0};
+
+const char * const known_sans_fonts[] = { "avant", "berasans", "cmbr", "cmss",
+"helvet", "lmss", 0};
+
+const char * const known_typewriter_fonts[] = { "beramono", "cmtl", "cmtt",
+"courier", "lmtt", "luximono", "fourier", "lmodern", "mathpazo", "mathptmx",
+"newcent", 0};
+
 // some ugly stuff
 ostringstream h_preamble;
 string h_textclass               = "article";
 string h_options                 = string();
 string h_language                = "english";
-string h_inputencoding           = "latin1";
-string h_fontscheme              = "default";
+string h_inputencoding           = "auto";
+string h_font_roman              = "default";
+string h_font_sans               = "default";
+string h_font_typewriter         = "default";
+string h_font_default_family     = "default";
+string h_font_sc                 = "false";
+string h_font_osf                = "false";
+string h_font_sf_scale           = "100";
+string h_font_tt_scale           = "100";
 string h_graphics                = "default";
 string h_paperfontsize           = "default";
 string h_spacing                 = "single";
@@ -99,18 +131,40 @@ void handle_opt(vector<string> & opts, char const * const * what, string & targe
 	if (opts.empty())
 		return;
 
-	for ( ; *what; ++what) {
-		vector<string>::iterator it = find(opts.begin(), opts.end(), *what);
+	// the last language option is the document language (for babel and LyX)
+	// the last size option is the document font size
+	vector<string>::iterator it;
+	vector<string>::iterator position = opts.begin();
+	for (; *what; ++what) {
+		it = find(opts.begin(), opts.end(), *what);
 		if (it != opts.end()) {
-			//cerr << "### found option '" << *what << "'\n";
-			target = *what;
-			opts.erase(it);
-			return;
+			documentclass_language = true;
+			if (it >= position) {
+				target = *what;
+				position = it;
+			}
 		}
 	}
 }
 
 
+void delete_opt(vector<string> & opts, char const * const * what)
+{
+	if (opts.empty())
+		return;
+
+	// remove found options from the list
+	// do this after handle_opt to avoid potential memory leaks and to be able
+	// to find in every case the last language option
+	vector<string>::iterator it;
+	for (; *what; ++what) {
+		it = find(opts.begin(), opts.end(), *what);
+		if (it != opts.end())
+			opts.erase(it);
+	}
+}
+
+
 /*!
  * Split a package options string (keyval format) into a vector.
  * Example input:
@@ -127,7 +181,7 @@ vector<string> split_options(string const & input)
 	while (p.good()) {
 		Token const & t = p.get_token();
 		if (t.asInput() == ",") {
-			options.push_back(option);
+			options.push_back(trim(option));
 			option.erase();
 		} else if (t.asInput() == "=") {
 			option += '=';
@@ -139,7 +193,7 @@ vector<string> split_options(string const & input)
 	}
 
 	if (!option.empty())
-		options.push_back(option);
+		options.push_back(trim(option));
 
 	return options;
 }
@@ -168,26 +222,98 @@ void add_package(string const & name, vector<string> & options)
 }
 
 
+// Given is a string like "scaled=0.9", return 0.9 * 100
+string const scale_as_percentage(string const & scale)
+{
+	string::size_type pos = scale.find('=');
+	if (pos != string::npos) {
+		string value = scale.substr(pos + 1);
+		if (isStrDbl(value))
+			return convert<string>(100 * convert<double>(value));
+	}
+	// If the input string didn't match our expectations.
+	// return the default value "100"
+	return "100";
+}
+
+
 void handle_package(string const & name, string const & opts)
 {
 	vector<string> options = split_options(opts);
 	add_package(name, options);
+	string scale;
 
-	//cerr << "handle_package: '" << name << "'\n";
-	if (name == "ae")
-		h_fontscheme = "ae";
-	else if (name == "aecompl")
-		h_fontscheme = "ae";
-	else if (name == "amsmath")
+	// roman fonts
+	if (is_known(name, known_roman_fonts))
+		h_font_roman = name;
+	if (name == "fourier") {
+		h_font_roman = "utopia";
+		// when font uses real small capitals
+		if (opts == "expert")
+			h_font_sc = "true";
+	}
+	if (name == "mathpazo")
+		h_font_roman = "palatino";
+	if (name == "mathptmx")
+		h_font_roman = "times";
+	// sansserif fonts
+	if (is_known(name, known_sans_fonts)) {
+		h_font_sans = name;
+		if (!opts.empty()) {
+			scale = opts;
+			h_font_sf_scale = scale_as_percentage(scale);
+		}
+	}
+	// typewriter fonts
+	if (is_known(name, known_typewriter_fonts)) {
+		h_font_typewriter = name;
+		if (!opts.empty()) {
+			scale = opts;
+			h_font_tt_scale = scale_as_percentage(scale);
+		}
+	}
+	// font uses old-style figure
+	if (name == "eco")
+		h_font_osf = "true";
+
+	else if (name == "amsmath" || name == "amssymb")
 		h_use_amsmath = "1";
-	else if (name == "amssymb")
-		h_use_amsmath = "1";
-	else if (name == "babel")
-		; // ignore this
+	else if (name == "babel" && !opts.empty()) {
+		// check if more than one option was used - used later for inputenc
+		// in case inputenc is parsed before babel, set the encoding to auto
+		if (options.begin() != options.end() - 1) {
+			one_language = false;
+			h_inputencoding = "auto";
+		}
+		// only set the document language when there was not already one set
+		// via the documentclass options
+		// babel takes the the last language given in the documentclass options
+		// as document language. If there is no such language option, the last
+		// option of its \usepackage call is used.
+		if (documentclass_language == false) {
+			handle_opt(options, known_languages, h_language);
+			delete_opt(options, known_languages);
+			if (is_known(h_language, known_french_languages))
+				h_language = "french";
+			else if (is_known(h_language, known_german_languages))
+				h_language = "german";
+			else if (is_known(h_language, known_ngerman_languages))
+				h_language = "ngerman";
+			else if (is_known(h_language, known_russian_languages))
+				h_language = "russian";
+			else if (is_known(h_language, known_ukrainian_languages))
+				h_language = "ukrainian";
+			h_quotes_language = h_language;
+		}
+	}
 	else if (name == "fontenc")
 		; // ignore this
 	else if (name == "inputenc") {
-		h_inputencoding = opts;
+		// only set when there is not more than one inputenc option
+		// therefore check for the "," character
+		// also only set when there is not more then one babel language option
+		if (opts.find(",") == string::npos && one_language == true)
+			h_inputencoding = opts;
 		options.clear();
 	} else if (name == "makeidx")
 		; // ignore this
@@ -196,13 +322,19 @@ void handle_package(string const & name, string const & opts)
 	else if (name == "graphicx")
 		; // ignore this
 	else if (is_known(name, known_languages)) {
-		if (is_known(name, known_french_languages)) {
+		if (is_known(name, known_french_languages))
 			h_language = "french";
-			h_quotes_language = "french";
-		} else {
+		else if (is_known(name, known_german_languages))
+			h_language = "german";
+		else if (is_known(name, known_ngerman_languages))
+			h_language = "ngerman";
+		else if (is_known(name, known_russian_languages))
+			h_language = "russian";
+		else if (is_known(name, known_ukrainian_languages))
+			h_language = "ukrainian";
+		else
 			h_language = name;
-			h_quotes_language = name;
-		}
+		h_quotes_language = h_language;
 
 	} else if (name == "natbib") {
 		h_cite_engine = "natbib_authoryear";
@@ -236,17 +368,25 @@ void handle_package(string const & name, string const & opts)
 
 void end_preamble(ostream & os, TextClass const & /*textclass*/)
 {
-	os << "#LyX file created by  tex2lyx 0.1.2\n"
-	   << "\\lyxformat 245\n"
+	os << "#LyX file created by tex2lyx " << PACKAGE_VERSION << "\n"
+	   << "\\lyxformat 247\n"
 	   << "\\begin_document\n"
 	   << "\\begin_header\n"
-	   << "\\textclass " << h_textclass << "\n"
-	   << "\\begin_preamble\n" << h_preamble.str() << "\n\\end_preamble\n";
+	   << "\\textclass " << h_textclass << "\n";
+	if (!h_preamble.str().empty())
+		os << "\\begin_preamble\n" << h_preamble.str() << "\n\\end_preamble\n";
 	if (!h_options.empty())
-	   os << "\\options " << h_options << "\n";
+		os << "\\options " << h_options << "\n";
 	os << "\\language " << h_language << "\n"
 	   << "\\inputencoding " << h_inputencoding << "\n"
-	   << "\\fontscheme " << h_fontscheme << "\n"
+	   << "\\font_roman " << h_font_roman << "\n"
+	   << "\\font_sans " << h_font_sans << "\n"
+	   << "\\font_typewriter " << h_font_typewriter << "\n"
+	   << "\\font_default_family " << h_font_default_family << "\n"
+	   << "\\font_sc " << h_font_sc << "\n"
+	   << "\\font_osf " << h_font_osf << "\n"
+	   << "\\font_sf_scale " << h_font_sf_scale << "\n"
+	   << "\\font_tt_scale " << h_font_tt_scale << "\n"
 	   << "\\graphics " << h_graphics << "\n"
 	   << "\\paperfontsize " << h_paperfontsize << "\n"
 	   << "\\spacing " << h_spacing << "\n"
@@ -343,6 +483,24 @@ TextClass const parse_preamble(Parser & p, ostream & os, string const & forcecla
 			string const opt1 = p.getOpt();
 			string const opt2 = p.getFullOpt();
 			string const body = p.verbatim_item();
+			// font settings
+			if (name == "\\rmdefault")
+				if (is_known(body, known_roman_fonts))
+					h_font_roman = body;
+
+			if (name == "\\sfdefault")
+				if (is_known(body, known_sans_fonts))
+					h_font_sans = body;
+
+			if (name == "\\ttdefault")
+				if (is_known(body, known_typewriter_fonts))
+					h_font_typewriter = body;
+
+			if (name == "\\familydefault") {
+				string family = body;
+				// remove leading "\"
+				h_font_default_family = family.erase(0,1);
+			}
 			// only non-lyxspecific stuff
 			if (   name != "\\noun"
 			    && name != "\\tabularnewline"
@@ -352,7 +510,11 @@ TextClass const parse_preamble(Parser & p, ostream & os, string const & forcecla
 			    && name != "\\lyxrightaddress"
 			    && name != "\\lyxdot"
 			    && name != "\\boldsymbol"
-			    && name != "\\lyxarrow") {
+			    && name != "\\lyxarrow"
+			    && name != "\\rmdefault"
+			    && name != "\\sfdefault"
+			    && name != "\\ttdefault"
+			    && name != "\\familydefault") {
 				ostringstream ss;
 				ss << '\\' << t.cs();
 				if (star)
@@ -372,16 +534,27 @@ TextClass const parse_preamble(Parser & p, ostream & os, string const & forcecla
 		}
 
 		else if (t.cs() == "documentclass") {
-			vector<string> opts;
-			split(p.getArg('[', ']'), opts, ',');
-			handle_opt(opts, known_languages, h_language);
-			if (is_known(h_language, known_french_languages))
-				h_language = "french";
+			vector<string> opts = split_options(p.getArg('[', ']'));
 			handle_opt(opts, known_fontsizes, h_paperfontsize);
+			delete_opt(opts, known_fontsizes);
 			// delete "pt" at the end
 			string::size_type i = h_paperfontsize.find("pt");
 			if (i != string::npos)
 				h_paperfontsize.erase(i);
+			// to avoid that the babel options overwrite the documentclass options
+			documentclass_language = false;
+			handle_opt(opts, known_languages, h_language);
+			delete_opt(opts, known_languages);
+			if (is_known(h_language, known_french_languages))
+				h_language = "french";
+			else if (is_known(h_language, known_german_languages))
+				h_language = "german";
+			else if (is_known(h_language, known_ngerman_languages))
+				h_language = "ngerman";
+			else if (is_known(h_language, known_russian_languages))
+				h_language = "russian";
+			else if (is_known(h_language, known_ukrainian_languages))
+				h_language = "ukrainian";
 			h_quotes_language = h_language;
 			h_options = join(opts, ",");
 			h_textclass = p.getArg('{', '}');
@@ -431,7 +604,6 @@ TextClass const parse_preamble(Parser & p, ostream & os, string const & forcecla
 			string opts = p.getOpt();
 			if (!opts.empty()) {
 				istringstream is(string(opts, 1));
-				//cerr << "opt: " << is.str() << "\n";
 				is >> nargs;
 			}
 			special_columns[name[0]] = nargs;
