@@ -13,24 +13,29 @@
 #ifndef TEX2LYX_H
 #define TEX2LYX_H
 
-#include "texparser.h"
-#include "lyxtextclass.h"
+#include "Parser.h"
+#include "TextClass.h"
 
 #include <iosfwd>
 #include <string>
 #include <vector>
 #include <map>
 
+
+namespace lyx {
+
+namespace support { class FileName; }
+
 class Context;
 
-/// in preamble.C
-LyXTextClass const parse_preamble(Parser & p, std::ostream & os, std::string const & forceclass);
+/// in preamble.cpp
+TextClass const parse_preamble(Parser & p, std::ostream & os, std::string const & forceclass);
 
 /// used packages with options
 extern std::map<std::string, std::vector<std::string> > used_packages;
+extern Layout_ptr captionlayout;
 
-
-/// in text.C
+/// in text.cpp
 std::string translate_len(std::string const &);
 
 void parse_text(Parser & p, std::ostream & os, unsigned flags, bool outer,
@@ -47,16 +52,16 @@ void parse_text_in_inset(Parser & p, std::ostream & os, unsigned flags,
 			 bool outer, Context const & context);
 
 
-/// in math.C
+/// in math.cpp
 void parse_math(Parser & p, std::ostream & os, unsigned flags, mode_type mode);
 
 
-/// in table.C
+/// in table.cpp
 void handle_tabular(Parser & p, std::ostream & os, bool is_long_tabular,
-                    Context & context);
+		    Context & context);
 
 
-/// in tex2lyx.C
+/// in tex2lyx.cpp
 std::string const trim(std::string const & a, char const * p = " \t\n\r");
 
 void split(std::string const & s, std::vector<std::string> & result,
@@ -74,7 +79,7 @@ char const * const * is_known(std::string const &, char const * const *);
  * \param o2 wether \newcommand had a second optional parameter
  */
 void add_known_command(std::string const & command, std::string const & o1,
-                       bool o2);
+		       bool o2);
 
 // Access to environment stack
 extern std::vector<std::string> active_environments;
@@ -111,6 +116,9 @@ extern std::string getParentFilePath();
  *  contains a preamble.
  *  \return true if the conversion was successful, else false.
  */
-bool tex2lyx(std::string const & infilename, std::string const & outfilename);
+bool tex2lyx(std::string const & infilename, support::FileName const & outfilename);
+
+
+} // namespace lyx
 
 #endif
