@@ -3,8 +3,9 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author André Pönitz
+ * \author Andr Pnitz
  * \author Jean-Marc Lasgouttes
+ * \author Uwe Sthr
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -104,8 +105,9 @@ string parse_text_snippet(Parser & p, unsigned flags, const bool outer,
 }
 
 
-char const * const known_latex_commands[] = { "ref", "cite", "label", "index",
-"printindex", "pageref", "url", "vref", "vpageref", "prettyref", "eqref", 0 };
+char const * const known_latex_commands[] = { "ref", "cite", "label",
+ "index", "printindex", "pageref", "url", "vref", "vpageref", "prettyref",
+ "eqref", 0 };
 
 /*!
  * natbib commands.
@@ -132,19 +134,23 @@ char const * const known_jurabib_commands[] = { "cite", "citet", "citep",
 "citefield", "citetitle", "cite*", 0 };
 
 /// LaTeX names for quotes
-char const * const known_quotes[] = { "glqq", "grqq", "quotedblbase",
-"textquotedblleft", "quotesinglbase", "guilsinglleft", "guilsinglright", 0};
+char const * const known_quotes[] = { "dq", "guillemotleft", "flqq", "og",
+"guillemotright", "frqq", "fg", "glq", "glqq", "textquoteleft", "grq", "grqq",
+"quotedblbase", "textquotedblleft", "quotesinglbase", "textquoteright", "flq",
+"guilsinglleft", "frq", "guilsinglright", 0};
 
 /// the same as known_quotes with .lyx names
-char const * const known_coded_quotes[] = { "gld", "grd", "gld",
-"grd", "gls", "fls", "frs", 0};
+char const * const known_coded_quotes[] = { "prd", "ard", "ard", "ard",
+"ald", "ald", "ald", "gls", "gld", "els", "els", "grd",
+"gld", "grd", "gls", "ers", "fls",
+"fls", "frs", "frs", 0};
 
 /// LaTeX names for font sizes
 char const * const known_sizes[] = { "tiny", "scriptsize", "footnotesize",
 "small", "normalsize", "large", "Large", "LARGE", "huge", "Huge", 0};
 
 /// the same as known_sizes with .lyx names
-char const * const known_coded_sizes[] = { "tiny", "scriptsize", "footnotesize",
+char const * const known_coded_sizes[] = { "default", "tiny", "scriptsize", "footnotesize",
 "small", "normal", "large", "larger", "largest",  "huge", "giant", 0};
 
 /// LaTeX 2.09 names for font families
@@ -786,6 +792,26 @@ void parse_environment(Parser & p, ostream & os, bool outer,
 		p.skip_spaces();
 	}
 
+	else if (name == "framed") {
+		eat_whitespace(p, os, parent_context, false);
+		parent_context.check_layout(os);
+		begin_inset(os, "Note Framed\n");
+		os << "status open\n";
+		parse_text_in_inset(p, os, FLAG_END, outer, parent_context);
+		end_inset(os);
+		p.skip_spaces();
+	}
+
+	else if (name == "shaded") {
+		eat_whitespace(p, os, parent_context, false);
+		parent_context.check_layout(os);
+		begin_inset(os, "Note Shaded\n");
+		os << "status open\n";
+		parse_text_in_inset(p, os, FLAG_END, outer, parent_context);
+		end_inset(os);
+		p.skip_spaces();
+	}
+
 	else if (!parent_context.new_layout_allowed)
 		parse_unknown_environment(p, name, os, FLAG_END, outer,
 					  parent_context);
@@ -1105,6 +1131,8 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 		Context & context)
 {
 	Layout_ptr newlayout;
+	// store the current selectlanguage to be used after \foreignlanguage
+	string selectlang;
 	// Store the latest bibliographystyle (needed for bibtex inset)
 	string bibliographystyle;
 	bool const use_natbib = used_packages.find("natbib") != used_packages.end();
@@ -1166,8 +1194,7 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 		// extended to other quotes, but is not so easy (a
 		// left english quote is the same as a right german
 		// quote...)
-		else if (t.asInput() == "`"
-			 && p.next_token().asInput() == "`") {
+		else if (t.asInput() == "`" && p.next_token().asInput() == "`") {
 			context.check_layout(os);
 			begin_inset(os, "Quotes ");
 			os << "eld";
@@ -1175,8 +1202,7 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 			p.get_token();
 			skip_braces(p);
 		}
-		else if (t.asInput() == "'"
-			 && p.next_token().asInput() == "'") {
+		else if (t.asInput() == "'" && p.next_token().asInput() == "'") {
 			context.check_layout(os);
 			begin_inset(os, "Quotes ");
 			os << "erd";
@@ -1185,6 +1211,24 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 			skip_braces(p);
 		}
 
+		else if (t.asInput() == ">" && p.next_token().asInput() == ">") {
+			context.check_layout(os);
+			begin_inset(os, "Quotes ");
+			os << "ald";
+			end_inset(os);
+			p.get_token();
+			skip_braces(p);
+		}
+
+		else if (t.asInput() == "<" && p.next_token().asInput() == "<") {
+			context.check_layout(os);
+			begin_inset(os, "Quotes ");
+			os << "ard";
+			end_inset(os);
+			p.get_token();
+			skip_braces(p);
+		}
+
 		else if (t.asInput() == "<"
 			 && p.next_token().asInput() == "<" && noweb_mode) {
 			p.get_token();
@@ -1628,8 +1672,8 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 				numberOfbbOptions++;
 			if (numberOfbbOptions == 4)
 				os << "\tBoundingBox "
-				   << opts["bbllx"] << opts["bblly"]
-				   << opts["bburx"] << opts["bbury"] << '\n';
+				   << opts["bbllx"] << " " << opts["bblly"] << " "
+				   << opts["bburx"] << " " << opts["bbury"] << '\n';
 			else if (numberOfbbOptions > 0)
 				cerr << "Warning: Ignoring incomplete includegraphics boundingbox arguments.\n";
 			numberOfbbOptions = 0;
@@ -1639,7 +1683,7 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 				numberOfbbOptions++;
 			if (numberOfbbOptions == 2)
 				os << "\tBoundingBox 0bp 0bp "
-				   << opts["natwidth"] << opts["natheight"] << '\n';
+				   << opts["natwidth"] << " " << opts["natheight"] << '\n';
 			else if (numberOfbbOptions > 0)
 				cerr << "Warning: Ignoring incomplete includegraphics boundingbox arguments.\n";
 			ostringstream special;
@@ -2032,6 +2076,27 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 			eat_whitespace(p, os, context, false);
 		}
 
+		else if (t.cs() == "selectlanguage") {
+			context.check_layout(os);
+			// save the language for the case that a \foreignlanguage is used 
+			selectlang = subst(p.verbatim_item(), "\n", " ");
+			os << "\\lang " << selectlang << "\n";
+			
+		}
+
+		else if (t.cs() == "foreignlanguage") {
+			context.check_layout(os);
+			os << "\n\\lang " << subst(p.verbatim_item(), "\n", " ") << "\n";
+			os << subst(p.verbatim_item(), "\n", " ");
+			// set back to last selectlanguage
+			os << "\n\\lang " << selectlang << "\n";
+		}
+
+		else if (t.cs() == "inputencoding")
+			// write nothing because this is done by LyX using the "\lang"
+			// information given by selectlanguage and foreignlanguage
+			subst(p.verbatim_item(), "\n", " ");
+		
 		else if (t.cs() == "LyX" || t.cs() == "TeX"
 			 || t.cs() == "LaTeX") {
 			context.check_layout(os);
@@ -2186,6 +2251,12 @@ void parse_text(Parser & p, ostream & os, unsigned flags, bool outer,
 			}
 		}
 
+		else if (t.cs() == "newline") {
+			context.check_layout(os);
+			os << "\n\\" << t.cs() << "\n";
+			skip_braces(p); // eat {}
+		}
+
 		else if (t.cs() == "input" || t.cs() == "include"
 			 || t.cs() == "verbatiminput") {
 			string name = '\\' + t.cs();
